﻿#target InDesign
#targetengine "setUpBaselineGrid"

/* DESCRIPTION: Set up the baseline grid */ 

/*
  
    + Adobe InDesign Version: CS6
    + Autor: Roland Dreger 
    + Datum: 20. Juli 2014
    
    + Zuletzt aktualisiert: 2. November 2014
    
    
    
    + Eingabefelder:
      In den Eingabefeldern koennen die Werte mit Einheiten eingegeben werden (z. B. 13 pt). 
      
      Mit den Pfeiltasten koennen die Werte erhoeht/verringert werden. Die Werte (Schrittweiten) werden aus den 
      Voreinstellungen des Dokuments ausgelesen.
      
      ++ Skript-Eingabefeld: »Grundlinienraster« -> »Werte« -> »Anfang:« 
         aus den InDesign-Voreinstellungen: »Einheiten und Einteilungen« -> »Tastaturschritte« -> »Pfeiltasten«
      
      ++ Skript-Eingabefeld: »Grundlinienraster« -> »Werte« -> »Einteilung alle:« 
         aus den InDesign-Voreinstellungen: »Einheiten und Einteilungen« -> »Tastaturschritte« -> »Schriftgrad-Zeilenabstand«
      
         Wird zusaetzlich die Shift-Taste gedrueckt wird die Schrittweite um den Faktor 10 erhoeht/verringert.
      
      ++ Skript-Eingabefeld: »Grundlinienraster« -> »Werte« -> »Anfang:«:
         Werden »Shift« + »Crtl« + »Pfeiltaste« geleichzeitig gedrueckt, wird der Wert im Eingabefeld 
         um den Betrag eines Zeilenabstandes erhoeht/verringert.
         
      ++ Skript-Eingabefelder fuer die manulle Eingabe der Stege (Raender):
         Einfach-Klick auf die Feldbeschriftung waehlt den Wert im Eingabegeld aus.
         Doppel-Klick auf die Feldbeschriftung rundet zudem den Wert im Eingabefeld.

    
    + Freies Script fuer private und kommerzielle Nutzung (Creativ Commons Lizenz: Roland Dreger, CC BY 3.0 AT). 
    + Verwendung auf eigene Gefahr.
    
    + Free Script for private and commercial use (Creativ Commons Licence: Roland Dreger, CC BY 3.0 AT). 
    + Use at your own risk.
    
       
    
    + Thanks to Kai Ruebsamen (ruebiarts.de) for his ideas to the script and 
      Dirk Becker for ScriptUI tips.
    
*/




var _global = {};



__main();



function __main() { 
  __showUI ();
} /* END function __main */



function __showUI() {
  
  if(app.documents.length == 0) { 
    _global = null;
    return; 
  }
  
  var _doc = app.activeDocument,
      _icons,
      _ui;
      
  _doc.gridPreferences.baselineGridShown = true; /* Grundlinienraster anzeigen: »true« or »false« */ 
  
  __defineLocalizeStrings();
  _icons = __defineIconsForUI(); 
  
  _ui = new Window("palette", localize(_global.uiHead));
  with (_ui) { 
    orientation = "row";
    alignChildren = ["fill","fill"];
    margins.top = 10;
    margins.bottom = 14; 
    spacing = 10; 
    var _leftColumn = add("group");
    with(_leftColumn) {
      orientation = "column";
      alignChildren = ["fill","fill"];
      var _baslineGridPanel = add("panel", undefined, localize(_global.baselineGridLabel));
      with(_baslineGridPanel) {
        alignChildren = "fill";
        spacing = 8;
        margins.top = 15;
        margins.bottom = 14;     
        var _optionsPanel = add("tabbedpanel");
        with(_optionsPanel) {  
          alignChildren = "fill";
          margins = [14,5,14,6];
          var _valuesTab = add("tab", undefined, localize(_global.valuesTabLabel));
          with(_valuesTab) {
            alignChildren = "fill";
            margins.top = 0;
            spacing = 8;
            var _relativeToGroup = add("group");
            with(_relativeToGroup) {
              orientation = "column";
              alignChildren = "left";
              spacing = 5;
              add("statictext", undefined, localize(_global.relativToLabel));
              var _relativeToDropdownList = [localize(_global.topOfThePageListItem),localize(_global.topOfTheMarginListItem)];
              var _relativeToDropdown = add("dropdownlist", undefined, _relativeToDropdownList); 
            } /* END _relativeToGroup */        
            var _startGroup = add("group");
            with(_startGroup) { 
              orientation = "column";
              alignChildren = "left";
              spacing = 0;
              margins.top = 5;
              var _startInputLabel = add("statictext", undefined, localize(_global.startLabel));
              var _startInputGroup = add("group");
              with(_startInputGroup) {
                spacing = 20;
                var _startInput = add("edittext", undefined, "", { multiline: false });
                with(_startInput) {
                  characters = 9;
                }
                /* Button _selectionStartUIButton */
                try {
                  var _selectionStartUIButton = add("iconbutton", undefined, _icons.selectionStart, { style: "toolbutton"} );
                  with (_selectionStartUIButton) {
                    size = [28,28];
                    helpTip = localize(_global.selectionStartHelpTip);
                  }
                } catch (e) { 
                  var _selectionStartUIButton = add("button", undefined, localize(_global.selection));
                  with (_selectionStartUIButton) {
                    helpTip = localize(_global.selectionStartHelpTip);
                  } 
                } /* END Button _selectionStartUIButton */
              } /* END _startInputGroup */
            } /* END _startGroup */       
            var _incrementGroup = add("group");
            with(_incrementGroup) {
              orientation = "column";
              alignChildren = "left";
              spacing = 0;
              var _incrementInputLabel = add("statictext", undefined, localize(_global.incrementEveryLabel));
              var _incrementInputGroup = add("group");
              with(_incrementInputGroup) {
                spacing = 20;
                var _incrementInput = add("edittext", undefined, "", { multiline: false });
                with(_incrementInput) {
                  characters = 9;
                }
                /* Button _selectionIncrementUIButton */
                try {
                  var _selectionIncrementUIButton = add("iconbutton", undefined, _icons.selectionIncrement, { style: "toolbutton"} );
                  with (_selectionIncrementUIButton) {
                    size = [28,28];
                    helpTip = localize(_global.selectionIncrementHelpTip);
                  }
                } catch (e) { 
                  var _selectionIncrementUIButton = add("button", undefined, localize(_global.selection));
                  with (_selectionIncrementUIButton) {
                    helpTip = localize(_global.selectionIncrementHelpTip);
                  } 
                } /* END Button _selectionIncrementUIButton */
              } /* END _incrementInputGroup */
            } /* END _incrementGroup */   
          } /* END tab _valuesTab */
          var _displayTab = add("tab", undefined, localize(_global.displayTabLabel));
          with(_displayTab) {
            alignChildren = "fill";
            margins.top = 0;
            spacing = 12;
            var _baselineColorGroup = add("group");
            with(_baselineColorGroup) {
              orientation = "column";
              alignChildren = "left";
              spacing = 5;
              add("statictext", undefined, localize(_global.baselineColorLabel));
              var _baselineColorDropdownList = __getUIColorList();
              var _baselineColorDropdown = add("dropdownlist", undefined, _baselineColorDropdownList);
              with(_baselineColorDropdown) {
                __setUIColorIcon(_baselineColorDropdown,_icons);
              }  
              var _userDefinedColorGroup = add("group");
              with(_userDefinedColorGroup) {
                spacing = 2;
                var _userDefinedRedLabel = add("statictext", undefined, "R:");
                var _userDefinedRed = add("edittext", undefined, "", { multiline: false });
                with(_userDefinedRed) {
                  characters = 3;            
                  helpTip = localize(_global.userDefinedHelpTip);
                }
                var _userDefinedGreenLabel = add("statictext", undefined, "\u00A0G:");
                var _userDefinedGreen = add("edittext", undefined, "", { multiline: false });
                with(_userDefinedGreen) {
                  characters = 3;
                  helpTip = localize(_global.userDefinedHelpTip);
                }
                var _userDefinedBlueLabel = add("statictext", undefined, "\u00A0B:");
                var _userDefinedBlue = add("edittext", undefined, "", { multiline: false });
                with(_userDefinedBlue) {
                  characters = 3; 
                  helpTip = localize(_global.userDefinedHelpTip);
                }
              } /* _userDefinedColorGroup */
            } /* END _baselineColorGroup */
            var _viewThresholdGroup = add("group");
            with(_viewThresholdGroup) {
              orientation = "column";
              alignChildren = "left";
              spacing = 5;
              var _viewThresholdInputLabel = add("statictext", undefined, localize(_global.viewThresholdLabel));
              var _viewThresholdInputGroup = add("group");
              with(_viewThresholdInputGroup) {
                spacing = 2;
                var _viewThresholdInput = add("edittext", undefined, "", { multiline: false });
                with(_viewThresholdInput) {
                  characters = 3;
                }
                var _viewThresholdInputUnit = add("statictext", undefined, localize(_global.percentage));
                with(_viewThresholdInputUnit) {
                  characters = 5;
                }
              } /* END _viewThresholdInputGroup */
            } /* END _viewThresholdGroup */
            var _gridsInBackGroup = add("group");
            with(_gridsInBackGroup) {
              margins.top = 2;
              var _gridsInBack = add ("checkbox", undefined, localize(_global.gridsInBackLabel));
            } /* END _gridsInBackGroup */
          } /* END tab _displayTab */
        } /* END tabpanel _optionsPanel */
      } /* END _baslineGridPanel */    
      var _actionGroup = add("group");
      with(_actionGroup) {
        orientation = "column";
        alignChildren = ["fill","fill"];
        margins = [16,0,16,0];
        var _actionGroupTopRow = add("group");
        with(_actionGroupTopRow) {    
          var _rulerUnitButtonGroup = add("group");
          with(_rulerUnitButtonGroup) {
            spacing = 4;
            /* Button _ptButton */
            try {
              var _ptButton = add("iconbutton", undefined, _icons.rulerUnitsBg, { style: "toolbutton" } );
              with (_ptButton) {
                graphics.font = "dialog:11.5";
                size = [31,20];
                helpTip = localize(_global.points);; 
                text = "pt";
              }
            } catch (e) { }
            /* END _ptButton */
            /* Button _mmButton */
            try {
              var _mmButton = add("iconbutton", undefined, _icons.rulerUnitsBg, { style: "toolbutton" } );
              with (_mmButton) {
                graphics.font = "dialog:11.5";
                size = [31,20];
                helpTip = localize(_global.mm);;
                text = "mm";
              }
            } catch (e) { } 
            /* END _mmButton */
            /* Button _cmButton */
            try {
              var _cmButton = add("iconbutton", undefined, _icons.rulerUnitsBg, { style: "toolbutton" } );
              with (_cmButton) {
                graphics.font = "dialog:11.5";
                size = [31,20];
                helpTip = localize(_global.cm);;
                text = "cm";
              }
            } catch (e) { } 
            /* END _cmButton */  
            /* Button _inchButton */
            try {
              var _inchButton = add("iconbutton", undefined, _icons.rulerUnitsBg, { style: "toolbutton" } );
              with (_inchButton) {
                graphics.font = "dialog:11.5";
                size = [31,20];
                helpTip = localize(_global.inches);
                text = localize(_global.inches);
              }
            } catch (e) { } 
            /* END _inchButton */
            /* Button _pButton */
            try {
              var _pButton = add("iconbutton", undefined, _icons.rulerUnitsBg, { style: "toolbutton" } );
              with (_pButton) {
                graphics.font = "dialog:11.5";
                size = [31,20];
                helpTip = localize(_global.picas);;
                text = "p";
              }
            } catch (e) { } 
            /* END _pButton */ 
            /* Button _pxButton */
            try {
              var _pxButton = add("iconbutton", undefined, _icons.rulerUnitsBg, { style: "toolbutton"} );
              with (_pxButton) {
                graphics.font = "dialog:11.5";
                size = [31,20];
                helpTip = localize(_global.pixels);;
                text = "px";
              }
            } catch (e) { } 
            /* END _pxButton */
          } /* END _rulerUnitButtonGroup */
        } /* END _actionGroupTopRow */
        var _actionGroupBottomRow = add("group");
        with(_actionGroupBottomRow) {
          alignChildren = ["fill","fill"]; 
          margins.top = 0;
          margins.bottom = 0;
          var _alignButtonLeftGroup = add("group");
          with(_alignButtonLeftGroup) {
            spacing = 4;          
            var _baselineGridVisibilityGroup = add("group");
            with(_baselineGridVisibilityGroup) {
              orientation = "stack";
              margins = [0,0,0,0];      
              /* Button _showGrid */
              try {
                var _showGrid = add("iconbutton", undefined, _icons.showBaselineGrid, { style: "toolbutton"} );
                with (_showGrid) {
                  size = [31,31];
                  helpTip = localize(_global.showGridHelpTip);
                }
              } catch (e) { 
                var _showGrid = add("button", undefined, localize(_global.showGridHelpTip));
                with (_showGrid) {
                  helpTip = localize(_global.showGridHelpTip);
                } 
              } /* END Button _showGrid */     
              /* Button _hideGrid */
              try {
                var _hideGrid = add("iconbutton", undefined, _icons.hideBaselineGrid, { style: "toolbutton"} );
                with (_hideGrid) {
                  size = [31,31];
                  helpTip = localize(_global.hideGridHelpTip);
                }
              } catch (e) { 
                var _hideGrid = add("button", undefined, localize(_global.hideGridHelpTip));
                with (_hideGrid) {
                  helpTip = localize(_global.hideGridHelpTip);
                } 
              } /* END Button _hideGrid */
            } /* END _baselineGridVisibilityGroup */
            /* Button _refreshUIButton */
            try {
              var _refreshUIButton = add("iconbutton", undefined, _icons.refresh, { style: "toolbutton"} );
              with (_refreshUIButton) {
                size = [31,31];
                helpTip = localize(_global.refreshHelpTip);
              }
            } catch (e) { 
              var _refreshUIButton = add("button", undefined, localize(_global.refreshHelpTip));
              with (_refreshUIButton) {
                helpTip = localize(_global.refreshHelpTip);
              } 
            } /* END Button _refreshUIButton */
          } /* END _alignButtonLeftGroup */
          var _alignButtonRightGroup = add("group"); 
          with(_alignButtonRightGroup) {
            orientation = "column";
            alignChildren = ["right","center"];
            margins = [5,5,0,5]
            var _cancelUI = add("button", undefined, localize(_global.cancel));
            with(_cancelUI) {
              helpTip = localize(_global.closeWinHelpTip);
            }
          } /* END _alignButtonRightGroup */ 
        } /* END _actionGroupBottomRow */
      } /* END _actionGroup */
    } /* END _leftColumn */   
    var _rightColumn = add("group");
    with(_rightColumn) {
      orientation = "column";
      alignChildren = ["fill","fill"];
      var _marginsPanel = add("panel", undefined, localize(_global.marginsPanelLabel));
      with(_marginsPanel) {
        orientation = "stack";
        alignChildren = ["fill","top"];
        margins.top = 0;
        margins.right = 0; 
        margins.bottom = 16;
        spacing = 0;
        var _autoMarginGroup = add("group");
        with(_autoMarginGroup) {
          alignChildren = ["fill","top"];
          margins = 0;
          spacing = 0;
          orientation = "column";
          var _setMarginsButtonGroup = add("group");
          with(_setMarginsButtonGroup) {
            orientation = "column";
            alignChildren = "right";
            margins = [0,0,0,0];
            /* Button _setMarginsButton */
            try {
              var _setMarginsButton = add("iconbutton", undefined, _icons.setMargins, { style: "toolbutton"} );
              with (_setMarginsButton) {
                size = [24,23];
                helpTip = localize(_global.setMarginsButtonHelpTip);
              }
            } catch (e) { 
              var _setMarginsButton = add("button", undefined, "M");
              with (_setMarginsButton) {
                helpTip = localize(_global.setMarginsButtonHelpTip);
              } 
            } /* END Button _setMarginsButton */
          } /* END _setMarginsButtonGroup */
          var _marginTopButtonGroup = add("group");
          with(_marginTopButtonGroup) {
            margins.right = 14;
            margins.bottom = 9;
            orientation = "column";
            alignChildren = "center";
            var _marginTopButton = add("button", undefined, localize(_global.marginsTopLabel));
            with(_marginTopButton) {
              preferredSize.height = 26;
              helpTip = localize(_global.adjustMarginTopHelpTip);
            }
          } /* END _marginTopButtonGroup */
          var _centerleftAndRightMarginButtonGroup = add("group");
          with(_centerleftAndRightMarginButtonGroup) {  
            margins.right = 14;
            orientation = "column";
            alignChildren = "center";
            var _leftAndRightMarginButtonGroup = add("group");
            with(_leftAndRightMarginButtonGroup) {           
              var _marginLeftButton = add("button", undefined, localize(_global.marginsLeftLabel));
              with(_marginLeftButton) {
                preferredSize.height = 26;
                helpTip = localize(_global.adjustMarginLeftHelpTip);
              }
              /* Button _allMarginsButton */
              try {
                var _allMarginsButton = add("iconbutton", undefined, _icons.textFrame, { style: "toolbutton"} );
                with (_allMarginsButton) {
                  size = [31,31];
                  helpTip = localize(_global.adjustAllMarginsHelpTip);
                }
              } catch (e) { 
                var _allMarginsButton = add("button", undefined, localize(_global.adjustAllMarginsButtonLabel));
                with (_allMarginsButton) {
                  helpTip = localize(_global.adjustAllMarginsHelpTip);
                } 
              } /* END Button _allMarginsButton */
              /* Button _flipMarginsButton */
              try {
                var _flipMarginsButton = add("iconbutton", undefined, _icons.flipMargins, { style: "toolbutton"} );
                with (_flipMarginsButton) {
                  size = [31,31];
                  helpTip = localize(_global.flipButtonHelpTip);
                }
              } catch (e) { 
                var _flipMarginsButton = add("button", undefined, localize(_global.flipButtonHelpTip));
                with (_flipMarginsButton) {
                  helpTip = localize(_global.flipButtonHelpTip);
                } 
              } /* END Button _flipMarginsButton */
              var _marginRightButton = add("button", undefined,  localize(_global.marginsRightLabel));
              with(_marginRightButton) {
                preferredSize.height = 26;
                helpTip = localize(_global.adjustMarginRightHelpTip);
              }
            } /* END _leftAndRightMarginButtonGroup */    
          } /* END _centerleftAndRightMarginButtonGroup */
          var _marginBottomButtonGroup = add("group");
          with(_marginBottomButtonGroup) {
            margins.top = 7;
            margins.right = 14;
            margins.bottom = 0;
            orientation = "column";
            alignChildren = "center";
            var _marginBottomButton = add("button", undefined,  localize(_global.marginsBottomLabel));
            with(_marginBottomButton) {
              preferredSize.height = 26;
              helpTip = localize(_global.adjustMarginBottomHelpTip);
            }  
          } /* END _marginBottomButtonGroup */
        } /* END _autoMarginGroup */
        var _manualMarginGroup = add("group");
        with(_manualMarginGroup) {
          visible = false;
          alignChildren = ["fill","top"];
          margins = 0;
          spacing = 0;
          orientation = "column";
          var _autoMarginsButtonGroup = add("group");
          with(_autoMarginsButtonGroup) {
            orientation = "column";
            alignChildren = "right";
            margins = [0,0,0,0];
            /* Button _setMarginsButton */
            try {
              var _autoMarginsButton = add("iconbutton", undefined, _icons.autoMargins, { style: "toolbutton"} );
              with (_autoMarginsButton) {
                size = [24,23];
                helpTip = localize(_global.autoMarginsButtonHelpTip);
              }
            } catch (e) { 
              var _autoMarginsButton = add("button", undefined, "A");
              with (_autoMarginsButton) {
                helpTip = localize(_global.autoMarginsButtonHelpTip);
              } 
            } /* END Button _setMarginsButton */
          } /* END _autoMarginsButtonGroup */
          var _marginsInputGroup = add("group");
          with(_marginsInputGroup) {
            alignChildren = ["fill","fill"]; 
            var _marginsLeftInputGroup = add("group");
            with(_marginsLeftInputGroup) {
              orientation = "column";
              alignChildren = "right";
              var _marginTopInputGroup = add("group");
              with(_marginTopInputGroup) {
                spacing = 4;
                var _marginTopInputLabel = add("statictext", undefined, localize(_global.marginTopLabel));
                var _marginTopInput = add("edittext", undefined, "", { multiline: false});
                with(_marginTopInput) { 
                  characters = 7; 
                }   
              } /* END _marginTopInputGroup */ 
              var _marginBottomInputGroup = add("group");
              with(_marginBottomInputGroup) {
                spacing = 4;
                var _marginBottomInputLabel = add("statictext", undefined, localize(_global.marginBottomLabel));
                var _marginBottomInput = add("edittext", undefined, "", { multiline: false });
                with(_marginBottomInput) { 
                  characters = 7; 
                }          
              } /* END _marginBottomInputGroup */ 
            } /* END _marginsLeftInputGroup */      
            var _marginsRightInputGroup = add("group");
            with(_marginsRightInputGroup) {
              orientation = "column";
              alignChildren = "right";
              margins.right = 30;
              var _marginLeftInputGroup = add("group");
              with(_marginLeftInputGroup) { 
                spacing = 4;
                var _marginLeftInputLabel = add("statictext", undefined, localize(_global.marginLeftLabel));
                with(_marginLeftInputLabel) {
                  justify = "right";
                  characters = 5;
                }
                var _marginLeftInput = add("edittext", undefined, "", { multiline: false });
                with(_marginLeftInput) { 
                  characters = 7; 
                } 
              } /* END _marginLeftInputGroup */ 
              var _marginRightInputGroup = add("group");
              with(_marginRightInputGroup) { 
                spacing = 4;
                var _marginRightInputLabel = add("statictext", undefined, localize(_global.marginRightLabel));
                with(_marginRightInputLabel) {
                  justify = "right";
                  characters = 5;
                }
                var _marginRightInput = add("edittext", undefined, "", { multiline: false });
                with(_marginRightInput) { 
                  characters = 7; 
                } 
              } /* END _marginRightInputGroup */   
            } /* END _marginsRightInputGroup */
          } /* END _marginsInputGroup */
          var _columnsInputGroup = add("group");
          with(_columnsInputGroup) {
            orientation = "row";
            alignChildren = ["right","fill"];
            margins.right = 30;
            margins.top = 20;
            var _numberOfColumnsInputGroup = add("group");
            with(_numberOfColumnsInputGroup) {       
              spacing = 4;
              var _numberOfColumnsInputLabel = add("statictext", undefined, localize(_global.columnsLabel));  
              var _numberOfColumnsInput = add("edittext", undefined, "", { multiline: false });
              with(_numberOfColumnsInput) { 
                characters = 2; 
              } 
            } /* END _numberOfColumnsInputGroup */
            var _gutterInputGroup = add("group");
            with(_gutterInputGroup) {
              spacing = 4;
              var _gutterInputLabel = add("statictext", undefined, localize(_global.gutterLabel));
              var _gutterInput = add("edittext", undefined, "", { multiline: false });
              with(_gutterInput) { 
                characters = 7; 
              }          
            } /* END _gutterInputGroup */
          } /* END _columnsInputGroup */
        } /* END _manualMarginGroup */
      } /* END_marginsPanel */ 
      var _basicTFPanel = add("panel", undefined, localize(_global.basicTFPanelLabel));
      with(_basicTFPanel) {
        alignChildren = "left";
        margins.top = 24;
        margins.bottom = 14;
        spacing = 14;   
        var _basicTFObjectStyleGroup = add("group");
        with(_basicTFObjectStyleGroup) {
          orientation = "column";
          alignChildren = "left";
          spacing = 5;
          add("statictext", undefined, localize(_global.basicTFObjectStyle));     
          var _basicTFObjectStyleDropdownList = __getObjectStyleNames();
          var _basicTFObjectStyleDropdown = add("dropdownlist", undefined, _basicTFObjectStyleDropdownList);
          with(_basicTFObjectStyleDropdown) {
            maximumSize.width = 230;
            if(_doc.allObjectStyles[2].isValid && _doc.allObjectStyles[2].name == localize(_global.objectStyleBasicTFName)) { 
              selection = 2; 
            }
          } /* END _basicTFObjectStyleDropdown */
        } /* END _basicTFObjectStyleGroup */
        var _basicTFFirstBaselineGroup = add("group");
        with(_basicTFFirstBaselineGroup) {
          orientation = "column";
          alignChildren = "left";
          spacing = 5;
          add("statictext", undefined, localize(_global.basicTFFirstBaselineLabel));     
          var _basicTFFirstBaselineOffsetGroup = add("group");
          with(_basicTFFirstBaselineOffsetGroup) {
            spacing = 15;
            var _firstBaselineOffsetDropdownList = [localize(_global.firstBaselineAscentOffset), localize(_global.firstBaselineCapHeight), localize(_global.firstBaselineLeadingOffset), localize(_global.firstBaselineXHeight), localize(_global.firstBaselineFixedHeight)];
            var _basicTFFirstBaselineOffsetDropdown = add("dropdownlist", undefined, _firstBaselineOffsetDropdownList);
            var _basicTFFirstBaselineMinGroup = add("group");
            with(_basicTFFirstBaselineMinGroup) {
              spacing = 0;
              var _basicTFFirstBaselineMinLabel = add("statictext", undefined, localize(_global.basicTFFirstBaselineMinLabel));
              var _basicTFFirstBaselineMin = add("edittext", undefined, "", { multiline: false });
              with(_basicTFFirstBaselineMin) {
                characters = 4;
              }
            } /* END _basicTFFirstBaselineMinGroup */
          try { 
            var _info = add("iconbutton",undefined,_icons.info,{style: "toolbutton"}); 
            with(_info) {
              visible = true;
              size = [24,24];
              helpTip = localize(_global.basicTFChangeStyleHint);
            } // END iconbutton _info  
          } catch(e){};
          } /* END _basicTFFirstBaselineOffsetDropdownGroup */ 
        } /* END _basicTFFirstBaselineGroup */ 
      } /* END _basicTFPanel */
    } /* END _rightColumn */
  } /* END _ui */
 
 
 

  /* Callbacks _ui */
  
  _ui.onActivate = function() { 
    
    if(app.documents.length == 0) { return; }
    
    _refreshUIButton.notify(); 
  }
   
  
  _relativeToDropdown.onChange = function() {
    
    if(app.documents.length == 0) { return; }
    if(_global.refresh == true) { return; }
    
    var _doc = app.activeDocument;
    
    switch (_relativeToDropdown.selection.index) {
      case 0 :
        _doc.gridPreferences.baselineGridRelativeOption = BaselineGridRelativeOption.TOP_OF_PAGE_OF_BASELINE_GRID_RELATIVE_OPTION;
        break;
      case 1 :
        _doc.gridPreferences.baselineGridRelativeOption = BaselineGridRelativeOption.TOP_OF_MARGIN_OF_BASELINE_GRID_RELATIVE_OPTION;
        break;
      default :   
    }
  }
  
  
  _startInputLabel.addEventListener("click", function (_event) { 
    
    if(_event.detail == 2 /* Double-Click */) {
      if(app.documents.length == 0) { return; }
      if(__round(_startInput)) { 
        __setDocPrefs(_startInput,"baselineStart");
      }
    }   
    __activate(_startInput);
  });
  
   
  _startInput.onChanging = function() {   
      
    if(app.documents.length == 0) { return; } 
    if(_global.refresh == true) { return; }
    
    __setDocPrefs(_startInput,"baselineStart");
  }

  
  _startInput.onDeactivate = function() {
    
    if(app.documents.length == 0) { return; }
    
    var _doc = app.activeDocument,
        _baselineStartValue = _doc.gridPreferences.baselineStart;
    
    _startInput.text = __convertToOutputFormat(_baselineStartValue);
  }


  _startInput.addEventListener("keydown", function (_event) { 
    
    if(app.documents.length == 0) { return; }
    
    var _step = app.activeDocument.viewPreferences.cursorKeyIncrement;
    __keydown (_event, this, "baselineStart", _step); 
  }); /* Increment and decrement values with arrow keys */


  _selectionStartUIButton.onDraw = __buttonOnDraw;

  _selectionStartUIButton.onClick = function() {
     
    if(app.documents.length == 0) { return; }
    
    __press(this);
    
    var _doc = app.activeDocument,
        _userZeroPoint,
        _firstIP,
        _baselineStart,
        _baselineStartValue;
    
    if(app.selection.length != 0 && app.selection[0].hasOwnProperty("insertionPoints")) {
      
      _userZeroPoint = _doc.zeroPoint; 
      _doc.zeroPoint = [0,0];
      
      try { 
        
        _firstIP = app.selection[0].insertionPoints[0];
        _baselineStart = _firstIP.baseline;
        
        if(_doc.gridPreferences.baselineGridRelativeOption == BaselineGridRelativeOption.TOP_OF_MARGIN_OF_BASELINE_GRID_RELATIVE_OPTION) {         
          _baselineStart -= app.activeWindow.activePage.marginPreferences.top;     
        }
        
        _doc.gridPreferences.baselineStart = _baselineStart;
        _baselineStartValue = _doc.gridPreferences.baselineStart;
        _startInput.text = __convertToOutputFormat(_baselineStartValue);
      } catch(e) {}
      
      _doc.zeroPoint = _userZeroPoint;
    
    } else {
      alert(localize(_global.noTextSelectedErrorMessage));
    }
  }


  _incrementInputLabel.addEventListener("click", function (_event) { 
    
    if(_event.detail == 2 /* Double-Click */) {
      if(app.documents.length == 0) { return; }
      if(__round(_incrementInput)) { 
        __setDocPrefs(_incrementInput,"baselineDivision");
      }
    }
    __activate(_incrementInput);
  });


  _incrementInput.onChanging = function() {  
      
    if(app.documents.length == 0) { return; }
    if(_global.refresh == true) { return; }
    
    __setDocPrefs(_incrementInput,"baselineDivision");  
  }


  _incrementInput.onDeactivate = function() {
    
    if(app.documents.length == 0) { return; }
    
    var _doc = app.activeDocument,
        _baselineDivisionValue = _doc.gridPreferences.baselineDivision;
       
    _incrementInput.text = __convertToOutputFormat(_baselineDivisionValue);
  }


  _incrementInput.addEventListener("keydown", function (_event) { 
    
    if(app.documents.length == 0) { return; }
    
    var _doc = app.activeDocument,
        _rulerUnit = _doc.viewPreferences.horizontalMeasurementUnits.toString(),
        _leadingKeyIncrement = _doc.textPreferences.leadingKeyIncrement,
        _step;
        
    _step = __convert(_leadingKeyIncrement, "pt", _rulerUnit);  
    if(_step == null) { return; }  
    __keydown (_event, this, "baselineDivision", _step); 
  }); /* Increment and decrement values with arrow keys */

  
  _selectionIncrementUIButton.onDraw = __buttonOnDraw;
  
  _selectionIncrementUIButton.onClick = function() {
    
    if(app.documents.length == 0) { return; }
    
    __press(this);
    
    var _doc = app.activeDocument,
        _userZeroPoint,
        _firstIP,
        _baselineDivision,
        _baselineDivisionValue;
    
    if(app.selection.length != 0 && app.selection[0].hasOwnProperty("insertionPoints")) {
      
      _userZeroPoint = _doc.zeroPoint; 
      _doc.zeroPoint = [0,0];     
      _firstIP = app.selection[0].insertionPoints[0];
      _baselineDivision = 0;
                  
      if (_firstIP.leading == Leading.AUTO) {
        _baselineDivision = _firstIP.pointSize*(_firstIP.autoLeading/100)
        _baselineDivision = _baselineDivision + " pt";
      }
      else {
        _baselineDivision = _firstIP.leading + " pt";
      }
      
      try { 
        _doc.gridPreferences.baselineDivision = _baselineDivision; 
        _baselineDivisionValue = _doc.gridPreferences.baselineDivision;      
        _incrementInput.text = __convertToOutputFormat(_baselineDivisionValue);
      } catch(e) { }
      
      _doc.zeroPoint = _userZeroPoint;
    
    } else {
      alert(localize(_global.noTextSelectedErrorMessage));
    }
  }


  _baselineColorDropdown.onChange = function() {
    
    if(app.documents.length == 0) { return; }
    if(_global.refresh == true) { return; }
    
    var _doc = app.activeDocument,
        _colorName = _baselineColorDropdown.selection.text,
        _colorEnum = __getUIColorEnum(_colorName);
          
    if(_colorName != localize(_global.userDefined)) {
      _doc.gridPreferences.baselineColor = UIColors[_colorEnum];  
    } else {     
      __setUserDefinedBaslineColor(); /* Wechsel von UI-Farbe auf »Benutzerdefiniert«: Farbwerte aus InDesign-UI nicht auslesbar */
    }
  } 


  _userDefinedRedLabel.addEventListener("click", function () { 
    __activate(_userDefinedRed);
  });


  _userDefinedRed.onChanging = function() {
    
    if(_global.refresh == true) { return; }
    __setUserDefinedBaslineColor();
  }


  _userDefinedGreenLabel.addEventListener("click", function () { 
    __activate(_userDefinedGreen);
  });


  _userDefinedGreen.onChanging = function() {
    
    if(_global.refresh == true) { return; }
    __setUserDefinedBaslineColor();
  }


  _userDefinedBlueLabel.addEventListener("click", function () { 
    __activate(_userDefinedBlue);
  });


  _userDefinedBlue.onChanging = function() {
    
    if(_global.refresh == true) { return; }
    __setUserDefinedBaslineColor();
  }


  _viewThresholdInputLabel.addEventListener("click", function () { 
    __activate(_viewThresholdInput);
  });


  _viewThresholdInput.onChanging = function() {  
      
    if(app.documents.length == 0) { return; }
    if(_global.refresh == true) { return; }
    
    var _doc = app.activeDocument,
        _viewThresholdInputNumber = Number(_viewThresholdInput.text.replace(",",".","g").replace("[a-z+-]","","gi"));   
    
    if(_viewThresholdInput.text != "" && !isNaN(_viewThresholdInputNumber) && _viewThresholdInputNumber >= 5 && _viewThresholdInputNumber <= 4000) {   
      try {
        _doc.gridPreferences.baselineViewThreshold = _viewThresholdInputNumber;
      } catch(e) { }
    } 
  }


  _gridsInBack.onClick = function() { 
    
    if(app.documents.length == 0) { return; }
    
    var _doc = app.activeDocument;
    
    if(_gridsInBack.value == true) {
       _doc.gridPreferences.gridsInBack = true;
    } else {
       _doc.gridPreferences.gridsInBack = false;
    }
  }


  _marginTopButton.onClick = function() {     
    __setMarginAuto("Top",true,false);
  }
  
  
  _marginLeftButton.onClick = function() {     
    __setMarginAuto("Left",true,false);
  }
  
  
  _marginRightButton.onClick = function() {     
    __setMarginAuto("Right",true,false);
  }
  
  
  _marginBottomButton.onClick = function() {     
    __setMarginAuto("Bottom",true,false);
  }


  _allMarginsButton.onDraw = __buttonOnDraw;

  _allMarginsButton.onClick = function() {  
    __press(this);
    __setMarginAuto("Top",true,true);
    __setMarginAuto("Left",false,false);
    __setMarginAuto("Right",false,false);   
    __setMarginAuto("Bottom",false,false); 
  }


  _flipMarginsButton.onDraw = __buttonOnDraw;

  _flipMarginsButton.onClick = function() {
    
    __press(this);
    
    if (app.scriptPreferences.version >= 6) {
      app.doScript(__flipMargins, ScriptLanguage.JAVASCRIPT , [], UndoModes.ENTIRE_SCRIPT, localize (_global.flipButtonHelpTip));  
    } else { 
      __flipMargins(); 
    }  
  }


  _setMarginsButton.onClick = function() {
    
    _manualMarginGroup.visible = true;
    _autoMarginGroup.visible = false;

    __insertMarginValues();
  }


  _autoMarginsButton.onClick = function() {

    _manualMarginGroup.visible = false;
    _autoMarginGroup.visible = true;
  
    __insertMarginValues();
  }
  
  
  _marginTopInputLabel.addEventListener("click", function (_event) { 
    
    if(_event.detail == 2 /* Double-Click */) {
      if(__round(_marginTopInput)) {
        _marginTopInput.notify();
      } 
    }
    __activate(_marginTopInput);
  });
  
  
  _marginTopInput.onChange = function() { 
    __setMarginManual("Top", _marginTopInput);
  }


  _marginTopInput.addEventListener("keydown", function (_event) { 
    
    if(app.documents.length == 0) { return; }
    
    var _step = app.activeDocument.viewPreferences.cursorKeyIncrement;
    __keydown (_event, this, "Top", _step); 
  }); /* Increment and decrement values with arrow keys */


  _marginBottomInputLabel.addEventListener("click", function (_event) {
    
    if(_event.detail == 2 /* Double-Click */) {
      if(__round(_marginBottomInput)) {
        _marginBottomInput.notify();
      }
    }
    __activate(_marginBottomInput);
  });


  _marginBottomInput.onChange = function() { 
    __setMarginManual("Bottom", _marginBottomInput);
  }
  
  
  _marginBottomInput.addEventListener("keydown", function (_event) { 
    
    if(app.documents.length == 0) { return; }
    
    var _step = app.activeDocument.viewPreferences.cursorKeyIncrement;
    __keydown (_event, this, "Bottom", _step); 
  }); /* Increment and decrement values with arrow keys */
  
  
  _marginLeftInputLabel.addEventListener("click", function (_event) { 
    
    if(_event.detail == 2 /* Double-Click */) {
      if(__round(_marginLeftInput)) {
        _marginLeftInput.notify();
      } 
    }
    __activate(_marginLeftInput);
  });
  
  
  _marginLeftInput.onChange = function() { 
    __setMarginManual("Left", _marginLeftInput);
  }
  
  
  _marginLeftInput.addEventListener("keydown", function (_event) { 
    
    if(app.documents.length == 0) { return; }
    
    var _step = app.activeDocument.viewPreferences.cursorKeyIncrement;
    __keydown (_event, this, "Left", _step); 
  }); /* Increment and decrement values with arrow keys */


  _marginRightInputLabel.addEventListener("click", function (_event) { 
    
    if(_event.detail == 2 /* Double-Click */) {
      if(__round(_marginRightInput)) {
        _marginRightInput.notify();
      }
    }
    __activate(_marginRightInput);
  });
  
  
  _marginRightInput.onChange = function() { 
    __setMarginManual("Right", _marginRightInput);
  }


  _marginRightInput.addEventListener("keydown", function (_event) { 
    
    if(app.documents.length == 0) { return; }
    var _step = app.activeDocument.viewPreferences.cursorKeyIncrement;
    __keydown (_event, this, "Right", _step); 
  }); /* Increment and decrement values with arrow keys */

  
  _numberOfColumnsInputLabel.addEventListener("click", function () { 
    __activate(_numberOfColumnsInput);
  });
  
  
  _numberOfColumnsInput.onChange = function() { 
    __setColumnCountManual(_numberOfColumnsInput);
  }


  _numberOfColumnsInput.addEventListener("keydown", function (_event) { 
    __keydown (_event, this, "columnCount", "1"); 
  }); /* Increment and decrement values with arrow keys */


  _gutterInputLabel.addEventListener("click", function (_event) { 
    
    if(_event.detail == 2 /* Double-Click */) {
      if(__round(_gutterInput)) {
        _gutterInput.notify();
      }
    }
    __activate(_gutterInput);
  });


  _gutterInput.onChange = function() { 
    __setColumnGutterManual(_gutterInput);
  }


  _gutterInput.addEventListener("keydown", function (_event) { 
    
    if(app.documents.length == 0) { return; }
    
    var _step = app.activeDocument.viewPreferences.cursorKeyIncrement;
    __keydown (_event, this, "columnGutter", _step); 
  }); /* Increment and decrement values with arrow keys */


  _basicTFObjectStyleDropdown.onChange = function() {
    
    if(app.documents.length == 0) { return; }
    if(_global.refresh == true) { return; }
    if(_basicTFObjectStyleDropdown.selection == null) { return; }
    
    __insertBasicTFValues(true); 
  }


  _basicTFFirstBaselineOffsetDropdown.onChange = function() { 
      
    if(app.documents.length == 0) { return; }
    if(_global.refresh == true) { return; }
    if(_global.insertBasicTFValues == true) { return; }
    
    var _doc = app.activeDocument,
        _basicTFObjectStyleIndex,
        _basicTFObjectStyle,
        _textFramePreferences;
    
    if(_basicTFObjectStyleDropdown.selection == null) { return; }   
    _basicTFObjectStyleIndex = _basicTFObjectStyleDropdown.selection.index;
    if(!_doc.allObjectStyles[_basicTFObjectStyleIndex].isValid) { return; }  
    _basicTFObjectStyle = _doc.allObjectStyles[_basicTFObjectStyleIndex]; 

    _textFramePreferences = _basicTFObjectStyle.textFramePreferences;

    switch (_basicTFFirstBaselineOffsetDropdown.selection.index) {
      case 0 :
        _textFramePreferences.firstBaselineOffset = FirstBaseline.ASCENT_OFFSET;
        break;
      case 1 :
        _textFramePreferences.firstBaselineOffset = FirstBaseline.CAP_HEIGHT;
        break;
      case 2 :
        _textFramePreferences.firstBaselineOffset = FirstBaseline.LEADING_OFFSET;
        break;
      case 3 :
        _textFramePreferences.firstBaselineOffset = FirstBaseline.X_HEIGHT;
        break;
      case 4 :
        _textFramePreferences.firstBaselineOffset = FirstBaseline.FIXED_HEIGHT;
        break;
      default :     
    }    
  } 


  _basicTFFirstBaselineMinLabel.addEventListener("click", function () { 
    __activate(_basicTFFirstBaselineMin);
  });

  
  _basicTFFirstBaselineMin.onChanging = function() {
  
    if(app.documents.length == 0) { return; }
    if(_global.refresh == true) { return; }
    
    var _doc = app.activeDocument,
        _basicTFObjectStyleIndex;

    if(_basicTFObjectStyleDropdown.selection == null) { return; }
    _basicTFObjectStyleIndex = _basicTFObjectStyleDropdown.selection.index;
    if(!_doc.allObjectStyles[_basicTFObjectStyleIndex].isValid) { return; }
    
    __setDocPrefs(_basicTFFirstBaselineMin,"minimumFirstBaselineOffset") 
  }
  
  
  _basicTFFirstBaselineMin.addEventListener("keydown", function (_event) { 
    
    if(app.documents.length == 0) { return; }
    
    var _step = app.activeDocument.viewPreferences.cursorKeyIncrement;
    __keydown (_event, this, "minimumFirstBaselineOffset", _step); 
  }); /* Increment and decrement values with arrow keys */



  _ptButton.onDraw = __buttonOnDraw;

  _ptButton.onClick = function() {
    
    if(app.documents.length == 0) { return; }
    
    __press(this);
    __setDocMeasurementUnits("POINTS");
    _refreshUIButton.notify();
  }  
  
  
  _mmButton.onDraw = __buttonOnDraw;
  
  _mmButton.onClick = function() {
    
    if(app.documents.length == 0) { return; }
    
    __press(this);
    __setDocMeasurementUnits("MILLIMETERS");
    _refreshUIButton.notify();   
  }
  
  
  _cmButton.onDraw = __buttonOnDraw;
  
  _cmButton.onClick = function() {
    
    if(app.documents.length == 0) { return; }
    
    __press(this);
    __setDocMeasurementUnits("CENTIMETERS");
    _refreshUIButton.notify();
  }
  
  
  _inchButton.onDraw = __buttonOnDraw;
  
  _inchButton.onClick = function() {
    
    if(app.documents.length == 0) { return; }
    
    __press(this);
    __setDocMeasurementUnits("INCHES");
    _refreshUIButton.notify(); 
  }
  
  
  _pButton.onDraw = __buttonOnDraw;
  
  _pButton.onClick = function() {
    
    if(app.documents.length == 0) { return; }
    
    __press(this);
    __setDocMeasurementUnits("PICAS");
    _refreshUIButton.notify();
  }
  
  
  _pxButton.onDraw = __buttonOnDraw;
  
  _pxButton.onClick = function() {
    
    if(app.documents.length == 0) { return; }
    
    __press(this);
    __setDocMeasurementUnits("PIXELS");
    _refreshUIButton.notify();
  }
  
  _refreshUIButton.onDraw = __buttonOnDraw;

  _refreshUIButton.onClick = function() {
      
    if(app.documents.length == 0) { return; }
    
    _global.refresh = true; 
    __press(this);
    __insertGridValues(true);
    __insertBasicTFValues(false);
    __insertMarginValues();
    __disableRulerUnitButton(_rulerUnitButtonGroup);
    _global.refresh = false;
    
    if(app.scriptPreferences.version < 8) {
      _optionsPanel.selection = _valuesTab; /* Korrigiert fehlerhafte Darstellung des Tab-Panel unter Win CS5 */
    }
  }


  _showGrid.onDraw = __buttonOnDraw;

  _showGrid.onClick = function() {  
      
    if(app.documents.length == 0) { return; }
    
    var _doc = app.activeDocument;
    
    _doc.gridPreferences.baselineGridShown = true;
    __press(this);
    _showGrid.visible = false;
    _hideGrid.visible = true;
  }

  
  _hideGrid.onDraw = __buttonOnDraw;

  _hideGrid.onClick = function() {  
      
    if(app.documents.length == 0) { return; }
    
    var _doc = app.activeDocument;
    
    _doc.gridPreferences.baselineGridShown = false; 
    __press(this);
    _showGrid.visible = true;
    _hideGrid.visible = false;
    
  } 


  _info.onClick = function() {
    alert(localize(_global.basicTFChangeStyleHint));
  }


  _cancelUI.onClick = function() { 
    _ui.close(2);
  }
  
  
  _ui.onClose = function() {
    _global = null;
  }
  
  /* END Callbacks _ui */

 
  
  
  /* Define global properties */
  _global.refresh = false;
  _global.insertBasicTFValues = false;
  _global.relativeToDropdownList = _relativeToDropdownList;
  _global.relativeToDropdown = _relativeToDropdown;
  _global.startInput = _startInput;
  _global.incrementInput = _incrementInput;
  _global.viewThresholdInput = _viewThresholdInput;
  _global.baselineColorDropdown = _baselineColorDropdown;
  _global.baselineColorDropdownList = _baselineColorDropdownList;
  _global.userDefinedRed = _userDefinedRed;
  _global.userDefinedGreen = _userDefinedGreen;
  _global.userDefinedBlue = _userDefinedBlue;
  _global.gridsInBack = _gridsInBack;
  _global.basicTFObjectStyleDropdown = _basicTFObjectStyleDropdown;
  _global.basicTFFirstBaselineOffsetDropdown = _basicTFFirstBaselineOffsetDropdown;
  _global.basicTFFirstBaselineMin = _basicTFFirstBaselineMin;
  _global.marginLeftInputLabel = _marginLeftInputLabel;
  _global.marginRightInputLabel = _marginRightInputLabel;
  _global.marginTopButton = _marginTopButton;
  _global.marginLeftButton = _marginLeftButton;
  _global.marginRightButton = _marginRightButton;
  _global.marginBottomButton = _marginBottomButton;
  _global.marginTopInput = _marginTopInput;
  _global.marginBottomInput = _marginBottomInput;
  _global.marginLeftInput = _marginLeftInput;
  _global.marginRightInput = _marginRightInput;
  _global.numberOfColumnsInput = _numberOfColumnsInput;
  _global.gutterInput = _gutterInput;
  _global.showGrid = _showGrid;
  _global.hideGrid = _hideGrid;
  /* END Define global properties */
  
  
  
  
  _ui.show();
  
  return;
} /* END function __showUI */


function __setDocPrefs(_input,_prop) {
    
  var _doc = app.activeDocument,
      _inputValue,   
      _rulerUnit = _doc.viewPreferences.horizontalMeasurementUnits.toString(),
      _inputValueInPoints,
      _minValueBaselineStart = 0,
      _maxValueBaselineStart = 1000,
      _minValueBaselineDivison = 1,
      _maxValueBaselineDivison = 8640,
      _minValueFirstBaselineOffset = 0,
      _maxValueFirstBaselineOffset = 8640,
      _basicTFObjectStyleIndex,
      _basicTFObjectStyle;
   
  _inputValue = __getConvertedInputValue (_input); 
  if(_inputValue == null) { return; } 
  
  switch (_prop) {
    case "baselineStart" :
      _inputValueInPoints = __convert(_inputValue,_rulerUnit,"pt");   
      if(_inputValueInPoints == null || _inputValueInPoints < _minValueBaselineStart || _inputValueInPoints > _maxValueBaselineStart) { return; }
      try { _doc.gridPreferences[_prop] = _inputValue; } catch(e) { alert(e); }
      break;
    case "baselineDivision" :
      _inputValueInPoints = __convert(_inputValue,_rulerUnit,"pt");   
      if(_inputValueInPoints == null || _inputValueInPoints < _minValueBaselineDivison || _inputValueInPoints > _maxValueBaselineDivison) { return; }
      try { _doc.gridPreferences[_prop] = _inputValue; } catch(e) { alert(e); }
      break;
    case "minimumFirstBaselineOffset" :
      _inputValueInPoints = __convert(_inputValue,_rulerUnit,"pt");
      if(_inputValueInPoints == null || _inputValueInPoints < _minValueFirstBaselineOffset || _inputValueInPoints > _maxValueFirstBaselineOffset) { return; }     
      if(_global.basicTFObjectStyleDropdown.selection == null) { return; }
      _basicTFObjectStyleIndex = _global.basicTFObjectStyleDropdown.selection.index;
      if(!_doc.allObjectStyles[_basicTFObjectStyleIndex].isValid) { return; }
      _basicTFObjectStyle = _doc.allObjectStyles[_basicTFObjectStyleIndex]; 
      try { _basicTFObjectStyle.textFramePreferences[_prop] = _inputValue; } catch(e) { alert(e); }
      break;
    case "Top" :
      __setMarginManual(_prop, _input);
      break;
    case "Bottom" :
      __setMarginManual(_prop, _input);
      break;
    case "Left" :
      __setMarginManual(_prop, _input);
      break;
    case "Right" :
      __setMarginManual(_prop, _input);
      break;
    case "columnCount" :
      __setColumnCountManual(_input);
      break; 
    case "columnGutter" :
      __setColumnGutterManual(_input);
      break;  
    default :     
  }

  return;
} /* END function __setDocPrefs */



function __keydown(_event, _inputField, _prop, _step) {
  
  if(app.documents.length == 0) { return; }
   
  var _doc = app.activeDocument,
      _inputNumber;
  
  _step = Number(_step);

  if(_event.shiftKey) {  
    if(_prop == "baselineStart" && (_event.metaKey || _event.ctrlKey)) { 
      app.select(NothingEnum.NOTHING); /* Ausgewaehltes Objekt wird bei gedruecker crtl-/cmd-Taste mit den Pfeiltasten verschoben */
      _step = _doc.gridPreferences.baselineDivision;
    } else {
      _step = _step * 10;
    }
  } 

  switch (_event.keyName) {
    case "Up":
      _inputNumber = __getConvertedInputValue (_inputField);
      _inputField.text = __convertToOutputFormat(_inputNumber + _step);
      __setDocPrefs(_inputField, _prop);
      break;
    case "Down": 
      _inputNumber = __getConvertedInputValue (_inputField);
      if((_inputNumber - _step) >= 0) {
        _inputField.text = __convertToOutputFormat(_inputNumber - _step);
        __setDocPrefs(_inputField, _prop);
      } 
      break;
    default:
  }
  
  /* Bugfix InDesign Version CC: Keyboard Event »keydown« wird 2-mal ausgeloest */
  if(_event.keyName == "Up" || _event.keyName == "Down") {
    _event.preventDefault(); 
  }

  return;
} /* END function __keydown */



function __insertGridValues(_refresh) {
  
  if(app.documents.length == 0) { return; }
  
  var _doc = app.activeDocument;
  
  if (_refresh || !_global.startInput.active) { 
    _global.startInput.text = __convertToOutputFormat(_doc.gridPreferences.baselineStart);
  } 
  
  if (_refresh || !_global.relativeToDropdown.active) {
  
    switch (_doc.gridPreferences.baselineGridRelativeOption) {
      case BaselineGridRelativeOption.TOP_OF_PAGE_OF_BASELINE_GRID_RELATIVE_OPTION :
        _global.relativeToDropdown.selection = 0;
        break;
      case BaselineGridRelativeOption.TOP_OF_MARGIN_OF_BASELINE_GRID_RELATIVE_OPTION :
        _global.relativeToDropdown.selection = 1;
        break;
      default :  
    } 
  }
  
  if (_refresh || !_global.incrementInput.active) {
    _global.incrementInput.text = __convertToOutputFormat(_doc.gridPreferences.baselineDivision);
  }

  if (_refresh || !_global.viewThresholdInput.active) {
    _global.viewThresholdInput.text = Math.round(_doc.gridPreferences.baselineViewThreshold);
  }

  if (_refresh || !_global.baselineColorDropdown.active) {
    var _baselineColor = _doc.gridPreferences.baselineColor;
    var _colorIndex = __getBaselineColorIndex(_baselineColor);   
    _global.baselineColorDropdown.selection = _colorIndex; 
    if(_colorIndex == _global.baselineColorDropdownList.length - 1) {
      _global.userDefinedRed.text = Math.round(_doc.gridPreferences.baselineColor[0]);
      _global.userDefinedGreen.text = Math.round(_doc.gridPreferences.baselineColor[1]);
      _global.userDefinedBlue.text = Math.round(_doc.gridPreferences.baselineColor[2]);
    } 
  }

  if(_doc.gridPreferences.gridsInBack) {
    _global.gridsInBack.value = true;
  } else {
    _global.gridsInBack.value = false;
  }
   
  if(_doc.gridPreferences.baselineGridShown) { 
    _global.showGrid.visible = false;
    _global.hideGrid.visible = true;
  } else {
    _global.showGrid.visible = true;
    _global.hideGrid.visible = false;
  }

  return;
} /* END function __insertGridValues */



function __getUIColorList() {
 
  var _allUIColors = [];
 
  for (var i in _global.uiColors) { 
    _allUIColors.push(_global.uiColors[i].toString());   
  } 
  
  return _allUIColors;
} /* END function __getUIColorList */



function __getUIColorEnum(_colorName) {
  
  for (var _colorEnum in _global.uiColors) { 
    if(_global.uiColors[_colorEnum] == _colorName) {
      return _colorEnum;
    }
  }
  
  return "GRID_BLUE";
} /* END function __getUIColorEnum */



function __getBaselineColorIndex(_baselineColor) {
  
  var _colorArrayLength = _global.baselineColorDropdownList.length,
      _baselineColorName = _global.uiColors[_baselineColor.toString()];
  
  for(var i=0; i<_colorArrayLength;i++) {   
    if(_baselineColorName == _global.baselineColorDropdownList[i]) {
      return i;
    }
  }

  return _colorArrayLength - 1;
} /* END function __getBaselineColorIndex */



function __setUserDefinedBaslineColor() {
  
  if(app.documents.length == 0) { return; }
  
  var _doc = app.activeDocument,
      _r = Number(_global.userDefinedRed.text),
      _g = Number(_global.userDefinedGreen.text),
      _b = Number(_global.userDefinedBlue.text);

  if(isNaN(_r) || _r > 255 || _r < 0) _r = 0;
  if(isNaN(_g) || _g > 255 || _g < 0) _g = 0;
  if(isNaN(_b) || _b > 255 || _b < 0) _b = 0;
      
  _doc.gridPreferences.baselineColor = [_r,_g,_b]; 
  _global.baselineColorDropdown.selection = _global.baselineColorDropdownList.length - 1;
  
  return;
} /* END function __setUserDefinedBaslineColor */



function __insertBasicTFValues(_onChange) {
  
  if(app.documents.length == 0) { return; }
  
  var _doc = app.activeDocument,
      _basicTFObjectStyleIndex,
      _basicTFObjectStyle,
      _firstBaselineOffset,
      _minimumFirstBaselineOffset;
  
  if(!_onChange) {    
    __refeshBasicTFObjectStyleDropdownList();
  }
  
  if(_global.basicTFObjectStyleDropdown.selection == null) { return; } 
  _basicTFObjectStyleIndex = _global.basicTFObjectStyleDropdown.selection.index;

  if(!_doc.allObjectStyles[_basicTFObjectStyleIndex].isValid) { return; }
  _basicTFObjectStyle = _doc.allObjectStyles[_basicTFObjectStyleIndex];
  _firstBaselineOffset = _basicTFObjectStyle.textFramePreferences.firstBaselineOffset;
  
  _global.insertBasicTFValues = true;
  
  switch (_firstBaselineOffset) {
    case FirstBaseline.ASCENT_OFFSET :
      _global.basicTFFirstBaselineOffsetDropdown.selection = 0;
      break;
    case FirstBaseline.CAP_HEIGHT :
      _global.basicTFFirstBaselineOffsetDropdown.selection = 1;
      break;
    case FirstBaseline.LEADING_OFFSET :
      _global.basicTFFirstBaselineOffsetDropdown.selection = 2;
      break;
    case FirstBaseline.X_HEIGHT :
      _global.basicTFFirstBaselineOffsetDropdown.selection = 3;
      break;
    case FirstBaseline.FIXED_HEIGHT :
      _global.basicTFFirstBaselineOffsetDropdown.selection = 4;
      break;
    default :     
  }

  _minimumFirstBaselineOffset = _basicTFObjectStyle.textFramePreferences.minimumFirstBaselineOffset;
  _global.basicTFFirstBaselineMin.text = _minimumFirstBaselineOffset;

  _global.insertBasicTFValues = false;
  return;
} /* END function __insertBasicTFValues */



function __refeshBasicTFObjectStyleDropdownList() {
  
  var _objectStyleNames = __getObjectStyleNames(),
      _selectedItemIndex,
      _selectedItemName;
      
  if(_global.basicTFObjectStyleDropdown.selection != null) {    
    _selectedItemIndex = _global.basicTFObjectStyleDropdown.selection.index;
    _selectedItemName = _global.basicTFObjectStyleDropdown.selection.text;
  }

  _global.basicTFObjectStyleDropdown.removeAll();
  
  for(var i=0; i<_objectStyleNames.length; i++) {
    switch (_objectStyleNames[i]) {
      case localize(_global.objectStyleBasicGridName) :
        _global.basicTFObjectStyleDropdown.add ("separator", undefined);
        break; 
      default :
        _global.basicTFObjectStyleDropdown.add("item", _objectStyleNames[i]);    
    }
  }

  _global.basicTFObjectStyleDropdown.items[0].enabled = false;
  _global.basicTFObjectStyleDropdown.items[1].enabled = false;
  
  if(_selectedItemIndex != null && 
     _global.basicTFObjectStyleDropdown.items[_selectedItemIndex] != null && 
     _global.basicTFObjectStyleDropdown.items[_selectedItemIndex].text == _selectedItemName) {
       
    _global.basicTFObjectStyleDropdown.selection = _selectedItemIndex;
  }

  return;
} /* END function __refeshBasicTFObjectStyleDropdownList() */



function __getObjectStyleNames() {
 
  var _doc = app.activeDocument,
      _allOStyles = _doc.allObjectStyles,
      _allOStylesLength = _allOStyles.length,
      _oStyle,
      _oStyleName = "",
      _allOStyleNames = [], 
      i;
 
  for (i=0; i<_allOStylesLength; i++) { 
    _oStyle = _allOStyles[i];
    _oStyleName = _oStyle.name;
    _oStyleName = __getStyleName(_oStyle,_oStyleName); 
    _allOStyleNames.push(_oStyleName);
  }

  function __getStyleName(_style,_styleName) {
    
    var _styleGroupName,
        _maxLength = 14,
        _suffix;
        
    if (_style.parent instanceof ObjectStyleGroup) { 
      
      _styleGroupName = _style.parent.name;
      
      if (_styleGroupName.length > _maxLength) {
        _suffix = "... > ";
      } else {
        _suffix = " > ";
      }   
      _styleName = _styleGroupName.substring(0,_maxLength) + _suffix + _styleName;
      _styleName = __getStyleName(_style.parent,_styleName); 
    }
    
    return _styleName;
  } /* END function __getStyleName */

  return _allOStyleNames;
} /* END function __getObjectStyleNames */



function __insertMarginValues() {
  
  if(app.documents.length == 0) { return; }
  
  var _doc = app.activeDocument,
      _selection = app.selection,
      _page;
          
  _page = __getPage(_selection);
  
  switch (_page.side) {
    case PageSideOptions.RIGHT_HAND :
    case PageSideOptions.LEFT_HAND :
      _global.marginLeftInputLabel.text = localize(_global.marginInsideLabel);
      _global.marginRightInputLabel.text = localize(_global.marginOutsideLabel);
      break;
    default :
      _global.marginLeftInputLabel.text = localize(_global.marginLeftLabel);
      _global.marginRightInputLabel.text = localize(_global.marginRightLabel);
  }
  
  _global.marginTopInput.text = __convertToOutputFormat(_page.marginPreferences.top); 
  _global.marginBottomInput.text = __convertToOutputFormat(_page.marginPreferences.bottom); 
  _global.marginLeftInput.text = __convertToOutputFormat(_page.marginPreferences.left); 
  _global.marginRightInput.text = __convertToOutputFormat(_page.marginPreferences.right); 
  _global.numberOfColumnsInput.text = Math.round(_page.marginPreferences.columnCount);
  _global.gutterInput.text = __convertToOutputFormat(_page.marginPreferences.columnGutter); 
  
  _global.marginTopButton.text = localize(_global.marginsTopLabel);
  _global.marginBottomButton.text = localize(_global.marginsBottomLabel);
  _global.marginLeftButton.text = localize(_global.marginsLeftLabel);
  _global.marginRightButton.text = localize(_global.marginsRightLabel);
  
  return;
} /* END function __insertMarginValues */



function __setMarginManual(_marginName, _inputValue) {

  if(app.documents.length == 0) { return; }
  
  var _doc = app.activeDocument,
      _selection = app.selection,
      _marginValue,
      _page,
      _pageHeight,
      _pageWidth, 
      _inputFieldName;

  _marginValue = __getConvertedInputValue (_inputValue); 
  if(_marginValue == null) { return; }

  _page = __getPage(_selection);
  _pageHeight = _page.bounds[2] - _page.bounds[0];
  _pageWidth = _page.bounds[3] - _page.bounds[1];

  switch (_marginName) {
    case "Top" :
      if(_marginValue >= 0 && _marginValue <= Math.floor(_pageHeight - Math.ceil(_page.marginPreferences.bottom))) {
        __setMarginPref(_marginValue);
      } else {
        app.select(NothingEnum.NOTHING);
        alert(localize(_global.marginValueError));      
      }
      break;
    case "Left" :
      if(_marginValue >= 0 && _marginValue <= Math.floor(_pageWidth - Math.ceil(_page.marginPreferences.right))) {
        __setMarginPref(_marginValue);
      } else {
        app.select(NothingEnum.NOTHING);
        alert(localize(_global.marginValueError));       
      }
      break;
    case "Bottom" :
      if(_marginValue >= 0 && _marginValue <= Math.floor(_pageHeight - Math.ceil(_page.marginPreferences.top))) {
        __setMarginPref(_marginValue);
      } else {
        app.select(NothingEnum.NOTHING);
        alert(localize(_global.marginValueError));       
      }
      break;
    case "Right" :
      if(_marginValue >= 0 && _marginValue <= Math.floor(_pageWidth - Math.ceil(_page.marginPreferences.left))) {
        __setMarginPref(_marginValue);
      } else {
        app.select(NothingEnum.NOTHING);
        alert(localize(_global.marginValueError));       
      }
      break;
    default :      
  }
  
  function __setMarginPref(_marginValue) { 
    
    _page.marginPreferences[_marginName.toLowerCase()] = _marginValue;
    _inputFieldName = "margin" + _marginName + "Input";
    _global[_inputFieldName].text = __convertToOutputFormat(_marginValue);
    return;
  }
  
} /* END function __setMarginManual */



function __setColumnCountManual(_inputValue) {
  
  if(app.documents.length == 0) { return; }
  
  var _doc = app.activeDocument,
      _selection = app.selection,
      _columnCount = parseInt(_inputValue.text),
      _gutterValue,
      _maxGutterValue,
      _page = __getPage(_selection);
  
  if(isNaN(_columnCount) || _columnCount < 1 || _columnCount > 216) { 
    app.select(NothingEnum.NOTHING);
    alert(localize(_global.errorColumnCountValue));   
    _global.numberOfColumnsInput.text = _page.marginPreferences.columnCount;
    return; 
  }

  _gutterValue = _page.marginPreferences.columnGutter;
  _maxGutterValue = __getMaxGutterValue(_page,_columnCount);
  
  if(Math.ceil(_gutterValue) < _maxGutterValue) { 
    _page.marginPreferences.columnCount = _columnCount;
    _inputValue.text = _page.marginPreferences.columnCount;
  } else {
    app.select(NothingEnum.NOTHING);
    alert(localize(_global.errorColumnGutterValue));   
    _page.marginPreferences.columnGutter = 0;
    _global.gutterInput.text = __convertToOutputFormat(_page.marginPreferences.columnGutter);
    _page.marginPreferences.columnCount = _columnCount;
    _inputValue.text = _page.marginPreferences.columnCount;
  }

  return;
} /* END function __setColumnCountManual */



function __setColumnGutterManual(_inputValue) {
  
  if(app.documents.length == 0) { return; }
  
  var _doc = app.activeDocument,
      _rulerUnit = _doc.viewPreferences.horizontalMeasurementUnits.toString(),
      _selection = app.selection,
      _gutterValueInPoints,
      _gutterValue,
      _maxGutterValue,
      _columnCount,
      _page;
  
  _gutterValue = __getConvertedInputValue (_inputValue);  
  if(_gutterValue == null) { return; }
  
  _gutterValueInPoints = __convert(_gutterValue,_rulerUnit,"pt");
  if(_gutterValueInPoints == null || _gutterValueInPoints < 0 || _gutterValueInPoints > 1440) { 
    app.select(NothingEnum.NOTHING);
    alert(localize(_global.errorColumnGutterValue));    
    return; 
  }

  _page = __getPage(_selection);
  _columnCount = _page.marginPreferences.columnCount;
  _maxGutterValue = __getMaxGutterValue(_page,_columnCount);
  
  if(Math.ceil(_gutterValue) < _maxGutterValue) { 
    _page.marginPreferences.columnGutter = _gutterValue;
    _global.gutterInput.text = __convertToOutputFormat(_page.marginPreferences.columnGutter); 
  } else {
    app.select(NothingEnum.NOTHING);
    alert(localize(_global.errorColumnGutterValue));   
    _page.marginPreferences.columnGutter = 0;
    _global.gutterInput.text = __convertToOutputFormat(_page.marginPreferences.columnGutter);
  } 
  
  return;
} /* END function __setColumnGutter */



function __getMaxGutterValue(_page,_pageColumnCount) { 
  
  var _pageWidth = _page.bounds[3] - _page.bounds[1],
      _pageMarginLeft = _page.marginPreferences.left,
      _pageMarginRight = _page.marginPreferences.right;
  
  if(_pageColumnCount == 1) {
    return Math.round(_pageWidth - _pageMarginLeft - _pageMarginRight);
  } else {
    return Math.round((_pageWidth - _pageMarginLeft - _pageMarginRight) / (_pageColumnCount - 1));
  }
} /* END function __getMaxGutterValue */



function __setMarginAuto(_marginName,_firstRound,_onClickAllMargins) {
      
  if(app.documents.length == 0) { return; }
  
  var _doc = app.activeDocument,
      _selection,
      _userZeroPoint,
      _userRulerOrigin, 
      _page,
      _pageHeight,
      _pageWidth, 
      _y1,
      _x1,       
      _y2, 
      _x2,
      _columnCount,
      _gutterWidth = -1;
  
  _userZeroPoint = _doc.zeroPoint;
  _userRulerOrigin = _doc.viewPreferences.rulerOrigin; 
  
  _doc.zeroPoint = [0,0];
  _doc.viewPreferences.rulerOrigin  = RulerOrigin.PAGE_ORIGIN;
  
  try {

    if(_doc.selection.length == 0) {   
      if(_firstRound) { 
        alert(localize(_global.noTextFrameSelectedErrorMessage)); 
      }
      return;    
    } else {  
      
      if(_doc.selection.length == 1) {
        _selection = _doc.selection[0];  
        if(!(_selection instanceof TextFrame)) {    
          if(_selection.hasOwnProperty("parentTextFrames") && _selection.parentTextFrames != null && _selection.parentTextFrames instanceof Array && _selection.parentTextFrames[0] instanceof TextFrame) {      
            _selection = _selection.parentTextFrames[0];      
          } else {       
            if(_firstRound) { 
              alert(localize(_global.noTextFrameSelectedErrorMessage)); 
            }
            return;   
          }  
        }  
        
        switch (_marginName) {
          case "Top" :
            _y1 = _selection.geometricBounds[0];
            break;
          case "Left" :
            _x1 = _selection.geometricBounds[1]; 
            break;
          case "Bottom" :
            _y2 = _selection.geometricBounds[2];
            break;
          case "Right" :
            _x2 = _selection.geometricBounds[3];
            break;
          default :      
        }    
      
        _columnCount = 1;
      } else {
        
        if(__onlyTextFrames(_doc.selection) && __onSamePage(_doc.selection)) {         
          
          switch (_marginName) {
            case "Top" :
              _y1 = __getExtreme(0,_doc.selection);
              break;
            case "Left" :
              _x1 = __getExtreme(1,_doc.selection); 
              break;
            case "Bottom" :
              _y2 = __getExtreme(2,_doc.selection);
              break;
            case "Right" :
              _x2 = __getExtreme(3,_doc.selection);
              break;
            default :      
          }

          if(_onClickAllMargins) {
            _gutterWidth = __getGutterWidth(_doc.selection);
            _columnCount = _doc.selection.length;
          }
        
          _selection = _doc.selection[0];       
        } else {
          
          if(_firstRound) { 
            alert(localize(_global.noTextFrameSelectedErrorMessage)); 
          }
          return;
        }
      }
    }
    
    _page = __getPage([_selection]);
    _pageHeight = _page.bounds[2] - _page.bounds[0];
    _pageWidth = _page.bounds[3] - _page.bounds[1];
 
    switch (_marginName) {
      case "Top" :
        if(_y1 >= 0 && _y1 <= Math.floor(_pageHeight - _page.marginPreferences.bottom)) {
          __setMarginPref(_y1);
        }
        break;
      case "Left" :
        if(_x1 >= 0 && _x1 <= Math.floor(_pageWidth - _page.marginPreferences[__shiftMarginName(_page, "Right")])) {
          __setMarginPref(_x1);
        } 
        break;
      case "Bottom" :
        if(_y2 >= 0 && (_pageHeight - _y2) >= 0 && (_pageHeight - _y2) <= Math.floor(_pageHeight - _page.marginPreferences.top)) {
          __setMarginPref(_pageHeight - _y2);
        }
        break;
      case "Right" :
        if(_x2 >= 0 && (_pageWidth - _x2) >= 0 && (_pageWidth - _x2) <= Math.floor(_pageWidth - _page.marginPreferences[__shiftMarginName(_page, "Left")])) {
          __setMarginPref(_pageWidth - _x2);
        }
        break;
      default :      
    }
    
    if(_firstRound && _onClickAllMargins) {
      if(_gutterWidth >= 0) {
       _page.marginPreferences.columnGutter = _gutterWidth;
      }
      _page.marginPreferences.columnCount = _columnCount; 
    }  
    
    function __setMarginPref(_marginValue) { 
      
      var _buttonName;
      
      _buttonName = "margin" + _marginName + "Button";
      _marginName = __shiftMarginName(_page, _marginName);
      _page.marginPreferences[_marginName] = _marginValue; 
      _global[_buttonName].text = __convertToOutputFormat(_marginValue);
      
      return;
    }
  
    function __shiftMarginName(_curPage, _curMarginName) {
      
      if(_curPage.side == PageSideOptions.LEFT_HAND) {
        switch (_curMarginName) {
          case "Left" :
            _curMarginName = "Right";
          break;
          case "Right" :
            _curMarginName = "Left";
          break;
        }
      }
    
      return _curMarginName.toLowerCase();
    }
  
  } catch(e) { alert(e); }
  
  _doc.zeroPoint = _userZeroPoint;
  _doc.viewPreferences.rulerOrigin = _userRulerOrigin;
  
  return;
} /* END function __setMarginAuto */



function __onlyTextFrames (_selectedObjects) {
  
  for(var i=0; i<_selectedObjects.length; i++) {    
    if(!(_selectedObjects[i] instanceof TextFrame)) {
      return false;
    } 
  }
  
  return true;
} /* END function __onlyTextFrames */



function __onSamePage (_selectedObjects) {

  for(var i=0; i<_selectedObjects.length; i++) {       
    if(_selectedObjects[i].parentPage == null) {
      return false;
    } 
  }
  
  for(var i=1; i<_selectedObjects.length; i++) {    
    
    if(_selectedObjects[i-1].parentPage != _selectedObjects[i].parentPage) {
      return false;
    } 
  }

 return true;
} /* END function __onSamePage */



function __getExtreme(_ca,_selectedObjects) {
  
  var _caValues = [];
  
  for(var i=0; i<_selectedObjects.length; i++) {
    _caValues.push(Number(_selectedObjects[i].geometricBounds[_ca]));
  }

  _caValues.sort(function(a, b) { return a - b; });

  switch (_ca) {
    case 0 :
    case 1 :
      return _caValues[0]; /* Minimum */
    case 2 :
    case 3 :
      return _caValues[_caValues.length -1]; /* Maximum */
    default : 
  }

  return null;
} /* END function __getExtreme */



function __getGutterWidth(_selectedObjects) {  
    
    if(_selectedObjects.length < 2) { return -1; }
  
    var _distances = [],
        _distance,
        _numOfObj = _selectedObjects.length,
        _numOfPosDistances = 0;
    
    for(var i=0; i<_numOfObj; i++) {
      for(var j=0; j<_numOfObj; j++) {
        if(i!=j) {
          _distance = _selectedObjects[i].geometricBounds[1] - _selectedObjects[j].geometricBounds[3];
          if(_distance > 0) {
            _distances.push(_distance);
          }
        }
      }  
    }
  
    for(var o=1; o<=_numOfObj; o++) {
      _numOfPosDistances += (o-1);
    }
  
    if(_numOfPosDistances == _distances.length) {    
      _distances.sort(function(a, b) { return a - b; });
      return Math.round(_distances[0] * 1000)/1000;
    } 
  
  return -1;
}  /* END function __getGutterWidth */



function __flipMargins() {
  
  if(app.documents.length == 0) { return; }
  if(app.activeDocument.documentPreferences.facingPages == false) { return; }
  
  var _doc = app.activeDocument,
      _activePage = app.activeWindow.activePage,
      _selection,
      _userZeroPoint,
      _userRulerOrigin;
      
  _userZeroPoint = _doc.zeroPoint;
  _userRulerOrigin = _doc.viewPreferences.rulerOrigin; 
  
  _doc.zeroPoint = [0,0];
  _doc.viewPreferences.rulerOrigin  = RulerOrigin.PAGE_ORIGIN;
    
  if(_doc.selection.length != 0) {   
    
    _selection = _doc.selection[0];  
    
    if(_selection instanceof TextFrame) {    
      if(_selection.hasOwnProperty("parentPage") && _selection.parentPage != null) {
        _activePage = _selection.parentPage;
      }
    } else {
      if(_selection.hasOwnProperty("parentTextFrames") && _selection.parentTextFrames != null && _selection.parentTextFrames instanceof Array && _selection.parentTextFrames[0] instanceof TextFrame) {      
        _selection = _selection.parentTextFrames[0]; 
        if(_selection.hasOwnProperty("parentPage") && _selection.parentPage != null) {
          _activePage = _selection.parentPage;
        }   
      }
    }
  }
  
  try {
    if((_activePage.parent instanceof Spread || _activePage.parent instanceof MasterSpread ) && _activePage.parent.pages.length == 2) {     
      if(_activePage.side == PageSideOptions.LEFT_HAND) {     
        if(_activePage.parent.pages[1].side == PageSideOptions.RIGHT_HAND) {         
          _activePage.parent.pages[1].marginPreferences.top = _activePage.parent.pages[0].marginPreferences.top;
          _activePage.parent.pages[1].marginPreferences.bottom = _activePage.parent.pages[0].marginPreferences.bottom;
          _activePage.parent.pages[1].marginPreferences.left = _activePage.parent.pages[0].marginPreferences.left;
          _activePage.parent.pages[1].marginPreferences.right = _activePage.parent.pages[0].marginPreferences.right; 
          _activePage.parent.pages[1].marginPreferences.columnCount = _activePage.parent.pages[0].marginPreferences.columnCount; 
          _activePage.parent.pages[1].marginPreferences.columnGutter = _activePage.parent.pages[0].marginPreferences.columnGutter;
        } else {
          alert(localize(_global.alertNoRightPage));
        }
      } else {      
        if(_activePage.parent.pages[0].side == PageSideOptions.LEFT_HAND) {         
          _activePage.parent.pages[0].marginPreferences.top = _activePage.parent.pages[1].marginPreferences.top;
          _activePage.parent.pages[0].marginPreferences.bottom = _activePage.parent.pages[1].marginPreferences.bottom;
          _activePage.parent.pages[0].marginPreferences.left = _activePage.parent.pages[1].marginPreferences.left;
          _activePage.parent.pages[0].marginPreferences.right = _activePage.parent.pages[1].marginPreferences.right;
          _activePage.parent.pages[0].marginPreferences.columnCount = _activePage.parent.pages[1].marginPreferences.columnCount; 
          _activePage.parent.pages[0].marginPreferences.columnGutter = _activePage.parent.pages[1].marginPreferences.columnGutter;
        } else {
          alert(localize(_global.alertNoLeftPage));
        }
      }
    } else {
      alert(localize(_global.alertTooManyPages));
    } 
  } catch(e) { alert(e); }
  
  _doc.zeroPoint = _userZeroPoint;
  _doc.viewPreferences.rulerOrigin = _userRulerOrigin;
  
  return;
} /* END function __flipMargins */



function __getConvertedInputValue(_input) {
     
  var _doc = app.activeDocument,
      _inputUnit = _input.text.toLowerCase().match("(inches_decimal|inches decimal|decimal inches|dezimalzoll|millimeters|millimeter|millimetres|millimetre|zentimeter|centimeters|centimeter|centimetres|centimetre|inches|points|point|punkte|punkt|pixels|pixel|agates|agaten|ciceros|cicero|inch|picas|pica|zoll|ag|px|pt|in|mm|cm|c|p|z|\")"), 
      _rulerUnit = _doc.viewPreferences.horizontalMeasurementUnits.toString(),  
      _inputTextSplit,
      _inputValue;

  if(_inputUnit != null) {   
    _inputTextSplit = _input.text.replace(",",".","g").toLowerCase().split(_inputUnit[0]); 
    _inputValue = Number(_inputTextSplit[0]) + (Number(_inputTextSplit[1])/12);  /* 2. Wert fuer Umrechnung von Pica und Cicero */
    _inputValue = __convert(_inputValue,_inputUnit[0],_rulerUnit);
  } else {
    _inputValue = _input.text.replace(",",".","g").match("\\d{0,}\\.{0,1}\\d{0,}");
  }
  
  if(_input.text == "" || _inputValue == null) { return null; }
  
  if(_inputValue instanceof Array) {
    _inputValue = Number(_inputValue[0]); 
  }

  if(isNaN(_inputValue)) { 
    return null; 
  } else {
    return _inputValue;
  } 
} /* END function __getConvertedInputValue */



function __convert(_value,_from,_to) {
  
  var _result = 0;
   
  _value = String(_value);
  _value = Number(_value.replace(",",".","g").match("\\d{0,}\\.{0,1}\\d{0,}"));
  _from = __unify(_from);
  _to = __unify(_to);
  
  if(isNaN(_value) || _from == ""  || _to == "") { return null; }
    
  switch (_from) { 
    
    /* _from */
    case "mm" :
      switch (_to) {       
        /* _to */
        case "pt" :
          _result = _value * 72 / 25.4;
          break;  
        /* _to */
        case "inch" :
          _result = _value / 25.4;
          break;
        /* _to */
        case "cm" :
          _result = _value / 10;
          break; 
        /* _to */
        case "p" :
          _result = _value * 72 / 25.4 / 12; 
          break;
        /* _to */
        case "c" :
          _result = _value * (1/(1000/2660)) / 12; 
          break;
        /* _to */
        case "ag" :
          _result = _value / 25.4 * 14;
          break;
        default :
          _result = _value;
      }        
      break;     
    
    /* _from */
    case "cm" :
      switch (_to) {       
        /* _to */
        case "pt" :
          _result = _value * 72 / 25.4 * 10;
          break;  
        /* _to */
        case "inch" :
          _result = _value / 25.4 * 10;
          break;
        /* _to */
        case "mm" :
          _result = _value * 10;
          break; 
        /* _to */
        case "p" :
          _result = _value * 72 / 25.4 * 10 / 12;
          break;
        /* _to */
        case "c" :
          _result = _value * (1/(1000/2660)) * 10 / 12;
          break; 
        /* _to */
        case "ag" :
          _result = _value / 25.4 * 10 * 14;
          break;
        default :
          _result = _value;
      }        
      break;
      
    /* _from */  
    case "pt" :   
      switch (_to) {    
        /* _to */
        case "mm" :
          _result = _value * (1/72) * 25.4;
          break; 
        /* _to */
        case "cm" :
          _result = _value * (1/72) * 25.4 / 10;
          break;
        /* _to */
        case "inch" :
          _result = _value * (1/72);
          break;
        /* _to */
        case "p" :
          _result = _value * (6/72);
          break;
        /* _to */
        case "c" :
          _result = _value * 25.4 / ((1000/2660) * 12 * 72);
          break; 
        /* _to */
        case "ag" :
          _result = _value * (1/72) * 14;
          break;      
        default :
          _result = _value;
      }
      break; 
      
    /* _from */
    case "inch" :  
      switch (_to) {
        /* _to */
        case "mm" :
          _result = _value * 25.4;
          break; 
        /* _to */
        case "cm" :
          _result = _value * 25.4 / 10;
          break;
        /* _to */
        case "pt" :
          _result = _value * 72;
          break;
        /* _to */
        case "p" :
          _result = _value * 72 / 12;
          break;
        /* _to */
        case "c" :
          _result = _value * (25.4/(1000/2660)) / 12;
          break;
        case "ag" :
          _result = _value * 14;
          break;          
        default :
          _result = _value;
      }
      break;   
      
    /* _from */  
    case "p" :   
      switch (_to) {    
        /* _to */
        case "mm" :
          _result = _value * (1/72) * 25.4 * 12;
          break; 
        /* _to */
        case "cm" :
          _result = _value * (1/72) * 25.4 / 10 * 12;
          break;
        /* _to */
        case "inch" :
          _result = _value * (1/72) * 12;
          break;
        /* _to */
        case "pt" :
          _result = _value * 12;
          break;
        /* _to */
        case "c" :
          _result = _value * 25.4 / ((1000/2660) * 72);
          break;
        /* _to */
        case "ag" :
          _result = _value * (1/72) * 12 * 14;
          break;  
        default :
          _result = _value;
      }
      break;  
      
      
    /* _from */  
    case "c" :   
      switch (_to) {    
        /* _to */
        case "mm" :
          _result = _value * (1000/2660) * 12;
          break; 
        /* _to */
        case "cm" :
          _result = _value * (1000/2660) / 10 * 12;
          break;
        /* _to */
        case "inch" :
          _result = _value * ((1000/2660)/25.4) * 12;
          break;
        /* _to */
        case "pt" :
          _result = _value * (1000/2660) * 12 * 72 / 25.4;
          break;
        /* _to */
        case "p" :
          _result = _value * (1000/2660) * 72 / 25.4;
          break;
        /* _to */
        case "ag" :
          _result = _value * ((1000/2660)/25.4) * 12 * 14;
          break;  
        default :
          _result = _value;
      }
      break; 
      
      /* _from */
    case "ag" :  
      switch (_to) {
        /* _to */
        case "mm" :
          _result = _value * 25.4 / 14;
          break; 
        /* _to */
        case "cm" :
          _result = _value * 25.4 / 10  / 14;
          break;
        /* _to */
        case "pt" :
          _result = _value * 72 / 14;
          break;
        /* _to */
        case "p" :
          _result = _value * 72 / 12 / 14;
          break;
        /* _to */
        case "c" :
          _result = _value * (25.4/(1000/2660)) / 12 / 14;
          break;
        case "inch" :
          _result = _value / 14;
          break;         
        default :
          _result = _value;
      }
      break;  
  
    default :
      _result = _value;
  }
  
  
  
  function __unify(_unit) {
    
    _unit = _unit.replace("\\s+","","gi").toLowerCase();
   
    switch (_unit) {    
      case "mm" :
      case "millimeter" :
      case "millimeters" :
      case "millimetre" :
      case "millimetres" :     
        return "mm"; 
      case "cm" :
      case "zentimeter" :
      case "centimeter" :  
      case "centimeters" : 
      case "centimetre" :  
      case "centimetres" :
        return "cm";
      case "pt" :
      case "point" :
      case "points" :
      case "punkt" :
      case "punkte" :
      case "pixel" :
      case "pixels" :
      case "px" :
        return "pt";
      case "in" :  
      case "inch" :
      case "inches" :
      case "zoll" :
      case "z" :
      case "dezimalzoll" :
      case "inches_decimal" :
      case "inches decimal" :
      case "decimal inches" :
      case "\"" :
        return "inch";   
      case "agates" :
      case "agaten" :
      case "ag" :
        return "ag";
      case "ciceros" :
      case "cicero" :
      case "c" :
        return "c";
      case "picas" :
      case "pica" :
      case "p" :
        return "p";
      default :
        return "";
    }
  } /* END function __unify */
   
  if(!isNaN(_result)) {
    return _result;
  } else {
    return null;
  }
} /* END function __convert */



function __convertToOutputFormat(_input) {
  
  var _output,
      _decimal,
      _docUnit = __getDocUnits();
  
  if(_docUnit == "p" || _docUnit == "c") {
  
    _decimal = (Number(_input) - parseInt(_input)) * 12;
    _decimal = Math.round(_decimal * 1000)/1000;
    _output = parseInt(_input) + _docUnit + _decimal;
  } else {    
    _output = Math.round(_input * 1000)/1000 + " " + _docUnit;
  }
 
  return _output;
} /* END __convertToOutputFormat */



function __getDocUnits() {
 
  if(app.documents.length == 0) { return ""; }
  
  var _doc = app.activeDocument,
      _unit = _doc.viewPreferences.horizontalMeasurementUnits.toString();
  
  switch (_unit) {
    case "MILLIMETERS" :
      _unit = "mm";
      break;
    case "CENTIMETERS" :
      _unit = "cm";
      break;
    case "POINTS" :
      _unit = "pt";
      break;
    case "INCHES" :
      _unit = localize(_global.inches);
      break;
    case "PIXELS" :
      _unit = "px";
      break;    
    case "AGATES" :
      _unit = "ag";
      break;  
    case "CICEROS" :
      _unit = "c";
      break;  
    case "PICAS" :
      _unit = "p";
      break;  
    case "INCHES_DECIMAL" :
      _unit = localize(_global.inches);;
      break;    
    default : 
      _unit = "";
  }
  
  return _unit;
} /* END function __getDocUnits() */



function __setDocMeasurementUnits(_unit) {
   
  var _doc = app.activeDocument;

  _doc.viewPreferences.horizontalMeasurementUnits = MeasurementUnits[_unit];
  _doc.viewPreferences.verticalMeasurementUnits = MeasurementUnits[_unit];
  
  return;
} /* END __setDocMeasurementUnits */



function __getPage(_appSelection) {
  
  var _textFrame,
      _page;
  
  if(_appSelection.length > 0) {
    _textFrame = __getTextFrame(_appSelection[0]);
    _page = __getPageOf(_textFrame);
  } else {
    _page = __getPageOf(null);
  }
  
  function __getTextFrame(_obj) {
    
    if(_obj != null) {
      if(_obj instanceof TextFrame) {
        return _obj;
      } else { 
        if(_obj.hasOwnProperty("parentTextFrames") && 
           _obj.parentTextFrames != null && 
           _obj.parentTextFrames instanceof Array && 
           _obj.parentTextFrames[0] instanceof TextFrame) {

          return _obj.parentTextFrames[0];
        }
      }
    }
     
    return null;
  } /* END function __getTextFrame */ 
  
  function __getPageOf(_obj) {

      if(_obj != null && _obj.hasOwnProperty("parentPage") && _obj.parentPage != null) {
        return _obj.parentPage;      
      } else {
        return app.activeWindow.activePage;
      }  
  } /* END function __getPageOf */
   
  return _page;
} /* END function __getPage */
    
    
    
function __buttonOnDraw(_obj) {
    
  var _x, 
      _y,
      _docUnit = __getDocUnits();
  
  try {
    with(this) {
      
      fillBrush = graphics.newBrush(graphics.BrushType.SOLID_COLOR, [0.635, 0.635, 0.635, 1]);
      
      if(_obj.hasOwnProperty("mouseOver") && _obj.mouseOver == true) {
        if(Number(app.scriptPreferences.version) > 8 && app.generalPreferences.uiBrightnessPreference < 0.5) {
          fillBrush = graphics.newBrush(graphics.BrushType.SOLID_COLOR, [0.95, 0.55, 0.21, 1]);
        } else {
          fillBrush = graphics.newBrush(graphics.BrushType.SOLID_COLOR, [0.19, 0.48, 0.82, 1]);
        }
      }
    
      textPen = graphics.newPen(graphics.PenType.SOLID_COLOR, [0,0,0,0.8], 1);
      graphics.drawOSControl();
      graphics.rectPath(0,0,size[0]+2,size[1]+2);
      graphics.fillPath(fillBrush);
      
      if(this.hasOwnProperty("icon") && icon) {
        graphics.drawImage(icon,1,1,size[0]-2,size[1]-2);
      }
    
      if(this.hasOwnProperty("text") && text) {
        if(text == _docUnit) {
          textPen = graphics.newPen(graphics.PenType.SOLID_COLOR, [0,0,0,0.3], 1);
        }
        _x = (size[0] - graphics.measureString(text,graphics.font)[0]) / 2,
        _y = (size[1] - graphics.measureString(text,graphics.font)[1]) / 2;
        graphics.drawString (text, textPen, _x, _y, graphics.font);
      }
    }
  } catch(e) { }
} /* END function __buttonOnDraw */   


function __press(_button) {
    with(_button) {
      bounds = [bounds[0]+1,bounds[1]+1,bounds[2]-1,bounds[3]-1];
      $.sleep(140);
      bounds = [bounds[0]-1,bounds[1]-1,bounds[2]+1,bounds[3]+1];
    }
  } /* END function _toggle */
      
    
function __disableRulerUnitButton(_buttonGroup) {
  
  var _numberOfChildren = _buttonGroup.children.length,
      _docRulerUnit = __getDocUnits();
  
  for(var i=0; i<_numberOfChildren; i++) {
    if(_buttonGroup.children[i].enabled == false) {
      _buttonGroup.children[i].enabled = true;
    }
    if(_buttonGroup.children[i].text == _docRulerUnit) {
      _buttonGroup.children[i].enabled = false;
    }
  }

  return;
} /* END function __enableRulerUnitButton */



function __round(_input) {
 
  var _inputValue,
      _outputValue,
      _affixes,
      _prefix = "",
      _suffix = "",    
      _docUnit = __getDocUnits(),
      _f = 1;
  
  _inputValue = __getConvertedInputValue(_input);
  _outputValue = __convertToOutputFormat(_inputValue);
  _affixes = _outputValue.split(_docUnit);
  
  if(_docUnit == localize(_global.inches)) { 
    _f = 10; 
  }

  _prefix = Math.round(_affixes[0].replace(",",".","g") * _f) / _f; 
  
  if(isNaN(_prefix)) { 
    return false 
  }  
  
  if(_affixes.length > 1 && _affixes[1] != "") { 
    
    var _suffix = Math.round(_affixes[1].replace(",",".","g"));
    
    if(isNaN(_suffix)) { 
      return false 
    }
  }

  if(_docUnit != "p" && _docUnit != "c") {
    _docUnit = " " + _docUnit;
  }
  _input.text =  _prefix + _docUnit + _suffix;

return true;
} /* END function __round() */



function __activate(_field) {
 
  _field.active = true;

return;
} /* END function __activate() */



function __setUIColorIcon(_baselineColorDropdown,_icons) {
  try { 
    with(_baselineColorDropdown) {
      items[0].image = _icons.lightBlue; 
      items[1].image = _icons.red;
      items[2].image = _icons.green;
      items[3].image = _icons.blue;
      items[4].image = _icons.yellow;
      items[5].image = _icons.magenta;
      items[6].image = _icons.cyan;
      items[7].image = _icons.gray;
      items[8].image = _icons.black;
      items[9].image = _icons.orange;
      items[10].image = _icons.darkGreen;
      items[11].image = _icons.teal;
      items[12].image = _icons.tan;
      items[13].image = _icons.brown;
      items[14].image = _icons.violet;
      items[15].image = _icons.gold;
      items[16].image = _icons.darkBlue;
      items[17].image = _icons.pink;
      items[18].image = _icons.lavender;
      items[19].image = _icons.brickRed;
      items[20].image = _icons.oliveGreen;
      items[21].image = _icons.peach;
      items[22].image = _icons.burgundy;
      items[23].image = _icons.grassGreen;
      items[24].image = _icons.ochre;
      items[25].image = _icons.purple;
      items[26].image = _icons.lightGray;
      items[27].image = _icons.charcoal;
      items[28].image = _icons.gridBlue;
      items[29].image = _icons.gridOrange;
      items[30].image = _icons.fiesta;
      items[31].image = _icons.lightOlive;
      items[32].image = _icons.lipstick;
      items[33].image = _icons.cuteTeal;
      items[34].image = _icons.sulphur;
      items[35].image = _icons.gridGreen;
      items[36].image = _icons.white;
    }
  } catch (e) {}
    
  return;
} /* END function __setUIColorIcon */




/* Icons fuer User Interface */
function __defineIconsForUI() {
  
  return { 
    refresh: "\u0089PNG\r\n\x1A\n\x00\x00\x00\rIHDR\x00\x00\x00\x1F\x00\x00\x00\x1F\b\x02\x00\x00\x00\u0090\u00CC\u0081n\x00\x00\x00\x19tEXtSoftware\x00Adobe ImageReadyq\u00C9e<\x00\x00\x01\u008BIDATx\u00DA\u00EC\u0094\u00BD\u00AB\u0082P\x18\u00C6\u00F3\u0083>\u00A6\x04#)\u0085\u0088K\u0090\u00D1T\u0093\u00AD\u00E6\u00E8\u00E0\u00BF\u00D8\u00DC\"4\u00DAR\u008B\u008B\x0E54T\u00C3\u0085\u00F0F_PC\u0094D\u00F5\\\u00E3^.W0:\u00D0\u00E63\x1D=\u0087\u00DFy}}\u009F\u0087\u00EAt:\u0089\u00B7\u0089N\u00BCS1=\u00A6\u00BF*\u00F6\u00E9\u0089\u00DB\u00ED6\u009F\u00CFg\u00B3\u00D9z\u00BD>\u009DN\u00A9TJ\x10\u0084\u008F@\x14E\u00E1\u0080\u00E38\u00CDf\u0093\u0084\u00BE\u00DF\u00EF\u00FB\u00FD\u00FEf\u00B3\u00C1\u009Aa\u0098L&s>\u009F?\x03\u008DF\u00A3v\u00BB=\u009DN\t\u00E9\u0087\u00C3\u00C14M\u00D4[(\x14\x1A\u008DF\u00B1XD\u00B1\u00D7\u00EB\u00D5\u00F3<\u00D7u\u0097\u00CBe\u00B7\u00DB\u00BD\\.$\u009D\x01\u00C5\u00B2,\u00A0\u00EB\u00F5\u00BA\u00A2(\u008F&|\u00FF(\u009A\u0096$I\x14E\\\u00BCZ\u00AD\b\u00FB\u008EoGCr\u00B9\\\u00AB\u00D5\n\u00EF\u00A2\u00F6\u00A7\u00E8(z\u00B9\\\u00D6u=\u0099L\u0086\u00B7v\u00BB\u00DD\u00F1x\u0094e\u00F9)\u009D\u008A3\u00F2\u00D5\u00BE\x0F\u0087\u00C3\u00BF\u008F\u00B5Z\u008D\u00E7\u00F9\x7Fg\u00B6\u00DB\u00AD\u00EF\u00FB\u0098\u00D7\u0097\u00E9\u0093\u00C9\u00E4w\r\u00B3\u0084\u00D1\u00D0`0\u0080\u00815M\u00C3\b\x10&A>\u009F\u0087\u0095\u00C2\u00F1`\u00DB6\u00D0\x18\u00D9R\u00A9D\u00D8w\u0096e1\u00D7\u00BD^o\u00B1X\u00C0_\x0F.\u00BC\u008A7\u00E3\u00F18\u009DN\u00AB\u00AA\n\x7F\u0091\u00A4\x18\x1AR\u00A9T\u00E0\u00D8\u00AF@\u00C8\x19\u00E0\u00903\x0F\u00F7\u00A3j\u00A0\u00B3\u00D9l\x04\u00811\f#\u0082\u008ED\u00ACV\u00AB\x1C\u00C7\u00A1pp\x11\f\u00F0\x17\x02\x07[\u0088\x07\u0084Z\u00EC\u00A6\u0098\x1E\u00D3\x7Ft\x17`\x00\u00BCn\u00B9\u00FDZh\u0091\u00E3\x00\x00\x00\x00IEND\u00AEB`\u0082",
    hideBaselineGrid: "\u0089PNG\r\n\x1A\n\x00\x00\x00\rIHDR\x00\x00\x00\x1F\x00\x00\x00\x1F\b\x02\x00\x00\x00\u0090\u00CC\u0081n\x00\x00\x00\x19tEXtSoftware\x00Adobe ImageReadyq\u00C9e<\x00\x00\x02RIDATx\u00DA\u00ECUM\u008B\u00B1Q\x18\x1E<,|$\x1Fih\x10\x16J\u008AdJDc\n\x1BE\u00B6\u00FE\u0090\u008D\u0095\u0085\u00B2\u0094,\b\x0B5\u009BYX\u00C8bDF\u0091,L\u00F9\u008C\u009A\u00F1\u0091\u0092|\u00CEUOi6\u00AF\u00F1\u00CE\u00F0\u00D6[\u00CE\u00E2\u00E9\u00E9>\u00D7\u00B9\u00CE}_\u00F7u\u00CE\u00A1D\u00A3\u00D1\u009B\u008B\r\u00EA\u00CD%\u00C7\u0095\u00FD\x7Fc\u00A7\u00D1hb\u00B1\u00F8R\u00EC\"\u0091(\u0099L\n\x04\u0082#\x18\u00E2g\u00D4\u00B7\u00B7\u00B7\u00B1Xl\u00B1X\u00CC\u00E7\u00F3\u00B3\u00E5\u00BE\u00D9l\u00F0e\u00B3\u00D9\u00E5r\u00B9\u00DDn{<\u009E\u00D5j\u00F5\u00AB\u00DC\u00DF\u00DF\u00DF\u00DF\u00DE\u00DE\u00BA\u00DD\u00EEd2\u0081\x0E>\u009F\x0F\u00C1\u00A7\u00A7\u00A7\u0087\u0087\u0087\u00DDnw|-q\u009C\u00F7\u00E5\u00E5\u00A5\u00DF\u00EF\u00E3\u009FN\u00A7\x0B\u0085\u00C2\u00C7\u00C7G\u00B9\\\x1E\b\x04\u00F6\u00FB}.\u0097k6\u009B&\u0093\t\u00F1\u00BFcGR\u00A5R\u00A9Z\u00AD\u0082E&\u0093i4\u009A\u00BB\u00BB;*\u0095\n\u0093\u00C4\u00E3q\u0082 \u00DCn7fQP&\u0093\u00D1\u00E9tF\u00A3\x11\u00B3'\u00B1C\u00DC\u00E7\u00E7g\u00AC\u00E4r\u00B9V\u00ABU\"\u0091\u0090q\u00C8\u008Ddk\u00B5\u009A\u00DF\u00EFg\u00B1X\u0088\x0F\x06\u0083|>\u00FF\u00FA\u00FA\u00FA\u00F1\u00F1\u00E1p8\u00B0\u00EB\u00F7]-\x14\n\u00A0\u0096J\u00A5\u0090\u00F8@\rw3\u0099\u00CCD\"\u0081\u00FFJ\u00A5B\x061\x0B\f\u0090\u00C0c\u00D5I\u009EA\x0F\u0091\u0085\u00DDn\u0087\u00D6\u0087\u00A0B\u00A1\b\u0087\u00C3d\x1B\u0087\u00C3\u00E1!\x0E\f\u0090\u00C0c\u00D5I\u00ECJ\u00A5\x12\u00E2\u00A0i\u00EB\u00F5\u00FA\u0090c*\u0095B\u00F9\x07\u00B3\x1F\u00C0\u00C0\x00\t\u00BCJ\u00A5:Iw\u008B\u00C5\u0082c\u0082b\u00D3\u00E9\u00B4\u00D3\u00E9D\u00E1\u00BD^\u00AFX,j\u00B5\u00DA\u00D1h\u0084\u00C6\u00A2\u0087$\u0092\u00D4}6\u009B\x01c6\u009BObG\u0099.\u0097\x0B\u009Ei\u00B5Z\x1C\x0E\u0087\u00CF\u00E7\u0087B!\u009B\u00CD\u00A6V\u00ABI\u00C0v\u00BB\u00EDt:\u00F5z\x1D\x19P(\x14\u00BD^\u00FF'\u00CFP\u008E\u00BC|\u00A8\x17\u00F9\x06\u0083AX\x1E\u00FAb\x1B\x06\u0083\u00B1\\.\u00A7\u00D3))\x1A\x14\u00FB\u0089\u00DF\u00C9\u0081\u0083\u0093\u00CDfq\u00A6\f\x06\x03\u0092\u0085\u00EE\u00D8\x0F9\u00F2x<H\u0081\u00F6\x1C\u00E1\u00FD\u0086\x1D\u00EE\x1E\u008F\u00C7\u00E8\u0098\u00D7\u00EB\u00C5uHj\rM`\u00CD3\u00DC\u00EF\u0090\"\x12\u0089\u00DC\u00DF\u00DF\u0083\u00FA\u00EB\u009D~\u009E\u00D7\u00A3\u00D1h\u0080\x17\u00A7\u00FC7o\x13q\u00E4\x06\u00FF\u00EA\u00EB\u00EB\u00AB}e\u00FF7\u00EC\u009F\x02\f\x00G4\f\x0E\u00FB\u00FB\x06\x13\x00\x00\x00\x00IEND\u00AEB`\u0082",
    showBaselineGrid: "\u0089PNG\r\n\x1A\n\x00\x00\x00\rIHDR\x00\x00\x00\x1F\x00\x00\x00\x1F\b\x02\x00\x00\x00\u0090\u00CC\u0081n\x00\x00\x00\x19tEXtSoftware\x00Adobe ImageReadyq\u00C9e<\x00\x00\x01\u00CCIDATx\u00DA\u00ECU\u00B9\u008A\u00C2P\x145\u0089\u0082\u008D+\x16\u00C1m\u0088\"\x166\x06\u008Dv\u008A`aa\u00E3/\u00FA\x15\x16\u0082\x10PpE\x10+E\u0089\x1B\u008A(*\x16\u008A\u00EB\x19\x1F\u0084a&\u00E02\u00C8\x14\u0093[=\u00AE\u00E7\u009D{\u00EFy\u00E7\x1A*\u009B\u00CDj\u00DE\x16\u00B4\u00E6\u009D\u00A1\u00B2\u00AB\u00EC\u00FF\u0089]{\x17\u00B1Z\u00ADz\u00BD\u00DEp8\\\u00AF\u00D7\u00BB\u00DDN\u00AF\u00D7\u009BL&\u0097\u00CB\u00E5\u00F1x\u00CCf\u00F3\u00EB\u00EC\u00CB\u00E5\u00B2R\u00A9\f\x06\u0083O\u009CVk4\x1A\u00ADV+\n,\x16\u008B\u00D9lV\u00AB\u00D5\u00DCnw$\x12A\u00F29\u00F6\u00CB\u00E5R\u00AF\u00D7\u009B\u00CD\u00E6\u00F9|v8\x1C\u0081@\x00\u00CD2\fC~=\u009DN\u00A3\u00D1\u00A8\u00DDn\u00A30\x0E\u00C1`0\x14\nQ\x14\u00F5\x10;.\u00E7\u00F3yI\u0092\u00D0l,\x16\u00B3\u00DB\u00EDH\x1E\u008F\u00C7j\u00B5:\u009DNY\u0096\u00E5y\u00FE\u00E3\x16\u0093\u00C9D\x14\u00C5F\u00A3\u0081i\u0092\u00C9\u00A4\\^\x0E&\u0093\u00C9|K\u0095J\u00A5n\u00B7\u008Bf\u00D3\u00E9\u00B4\u00ACl\u00B1Xl\u00B5Z\u00DB\u00ED\x16\x05 \x0E\u00A8\u00914\x18\f~\u00BF\x1F\u00D4\x18b\u00BF\u00DFC\u00A8\u00FB\u009E\u00E9t:P9\u0091H\u00E8t:9\u00896\x15\u00CF\u00C0\x00\t<n=\u00E4H\u009F\u00CF\x07\x1D\n\u0085\u00C2\u00E1p\u0090\u0093P_\u00F1\f\f\u0090\u00C0\u00E3\u00D6O*\x05e\u009CN'\x19\x16F\u0084\x1F0>\u0092D}<\x1DX\x04A\u00A0i\u009A\f\u0091\u00CB\u00E5\u00E6\u00F39\u0084\u008A\u00C7\u00E3$\u00F95(\u00C5o\u00D3]\u00CF\u00C0\u00FE\u00F0\u00CCx<\x06\u00E3s\u009E!=\u0086\u00C3a\u00AF\u00D7[.\u00971\x04X\u0088\u00DF\u00B1Jx\u00D2\u00CDf\x03)\x00\u00C33F\u00A3Q\u008B\u00C5\u00F2\u00CA6\u00E1Z*\u0095\u00C2\u00AE\u00F6\u00FB}4\u008B\x03\u00F6\x0B\x05l6\x1BF\u00E18\u00EEW\u00BBJ\x02\x14\u00FC-\u00D4\x7F`\u0095]e\u00FFC\u00F6\u00AB\x00\x03\x00\u00C7\u00EF\u00EB\u00D0\x00I+\x06\x00\x00\x00\x00IEND\u00AEB`\u0082",
    selectionStart: "\u0089PNG\r\n\x1A\n\x00\x00\x00\rIHDR\x00\x00\x00\x1C\x00\x00\x00\x1C\b\x02\x00\x00\x00\u00FDoH\u00C3\x00\x00\x00\x19tEXtSoftware\x00Adobe ImageReadyq\u00C9e<\x00\x00\x01\u00A4IDATx\u00DAb\\\u00B4h\x11\x03\u00B5\x01\x13\x03\r\u00C0\b7\u0094\u0085$\u00D5\u00B3f\u00CD\x1AR\u00DE\u00EF\u00E8\u00E8\u00D0\u00D1\u00D1\u00A1\u00A1Kyxx\u00DC\u00DD\u00DD\u00ED\u00EC\u00EC \\\x7F\x7F\x7F\t\t\t\x16\n\r\u00CD\u00CF\u00CF\x7F\u00F5\u00EA\x15??\u00BF\u0082\u0082\x020\x1FYZZ\u00CA\u00C9\u00C9\u00A1\x1B\u00AA\u00A9\u00A9)++\u008B,\u00F2\u00F8\u00F1\u00E3\u00EB\u00D7\u00AFc5\x11\x18\b\u00BC\u00BC\u00BC\u00AD\u00AD\u00AD@FLL\fDp\u00FF\u00FE\u00FD\u00E8\u0086\u00DE\u00B8q\u0083\u0083\u0083CTT\x14\u00C2}\u00FD\u00FA5P\x04\u00D38iii \u00F9\u00ED\u00DB\u00B7\u009F?\x7F\x02\u00BD/..\u00FE\u00F4\u00E9S\u009Ca\u00FA\u00FF\u00FF\u00FFK\u0097.}\u00FC\u00F8\x11\u00C8\x06\u0092@6P\x04M\rP\u00BF\u009A\u009A\u009A\u00A3\u00A3\u00A3\u008C\u008C\u00CC\u00EA\u00D5\u00AB\u0081\u00FE\x05\n\x02\x19\x10)\u00A0M\u008CX\x0B\x14666\u00A0\u008F\u00AE\\\u00B9\u00F2\u00EB\u00D7/2\u00D2)\u008A\u00F7\u00DD\u00DC\u00DC\u0090\u00B9\x0E\x0E\x0Ep\u00F6\u00AE]\u00BB\u0088\u008F=\u00C6a]\u00F4\x01\u00A3\u0082\u00CA\u0086~\u00F8\u00F0a\u00EB\u00D6\u00AD\u00BF\x7F\u00FF\u00A6\u00A6\u00A1\u00DC\u00DC\u00DC\u00C0\bdee\x05\u009A\x0E4\x1AB\u00C2\x135\u0084\u00CDB\u0086K\u00D7\u00AF_\u009F\u0096\u0096v\u00EA\u00D4\u00A9\x1F?~@\u0092spp\u00F0\u009E={ \n<==)\u008A(%%%???`\u00C6\u00BFw\u00EF\x1E\u0090\x0B\u00CC\u008A\u00C0\u00BC\x0F\u00F4\x04E\u0086\x02\u00B3\x06\u00D0\u00BF\u00C0\u009C\n\f\x13\x17\x17\x17mmm\u00A0'\u0080^\u00A1\u00A8\u0094\u00BA{\u00F7\u00EE\u00993g\u0080\u00E5\x130\u00BF\x1E;v\u00EC\u00E6\u00CD\u009B@\u00B6\u0080\u0080\x00\u00F9\u0089\x1F\u0098\u00C7\u00A4\u00A4\u00A4\u00B0\u0096\u00D6\u00E4\u00BBTUU\x15XBS\u00A1\u00E2C\x06\u008A\u008A\u008At\u00CD\u00A6\x00\x01\x06\x00\u00E2+\u00B0\u00B7>V\u0097\u00DB\x00\x00\x00\x00IEND\u00AEB`\u0082",
    selectionIncrement: "\u0089PNG\r\n\x1A\n\x00\x00\x00\rIHDR\x00\x00\x00\x1C\x00\x00\x00\x1C\b\x02\x00\x00\x00\u00FDoH\u00C3\x00\x00\x00\x19tEXtSoftware\x00Adobe ImageReadyq\u00C9e<\x00\x00\x01\u00C0IDATx\u00DA\u00D4\u0095\u00BF\u00CBAa\x14\u00C7y\u00F3\u00AB\x10\u00C9\u00AF\u0090X\f2H\x12\u008B\u00B20H\x06\u008B\u00BF\u00C0\u00EA\u00DF\u00F07\u00B0Y\r\x06\u008B\u00A4\u00AC\x06E\u00C9b\u00A0\u0094\u0085\x12\u008B\u0092\u00C5\u00A7\u009Ez\u00CB\u00FB^r\u00B9\u0094g8}\u00EFs\u00CF=\u00CF9\u00DF\u00E7{\u00CEU7\u009BM\u0095\u00D2\u00EBG\u00F5\u0086\u00F5=A5\u00B2\u00BC\u00EB\u00F5\u00FAW\u0095_\u00AB\u00D5\"\u0091\u00C8\x1B35\u0099L\u00B9\\.\u009DN\u008B\u00C7b\u00B1\u00E8v\u00BB5/\x06\u00ADV\u00AB\u009B\u00CD\u00C6b\u00B1\x04\x02\x01$\u009FJ\u00A5\u00FC~\u00FFK\u0099B\u0082\u00D9ln4\x1A\u00DDn7\x1C\x0E\u008B\u00CD\u00C1`\u00F0d\u00A6^\u00AF\x17{<\x1EO\u00A7\x13\u00E5\u00BB\\\u00AE\u00F5z\u00FD\x12\u00A7|\x1F\n\u00852\u0099\u008C\u00CF\u00E7k\u00B5Z\u00D4\u00CB&@\u00BC\u00E2$\u00B5\u00AC\u00DE\x7FP\u00A7W\u00E5g\u00B3\u00D9[~\u00BD^\u00EF\u00F1\u00B3\u00A53\u00D5\u00EB\u00F5\u00D1ht2\u0099@\u00992\u00E2\u00D7j\u00B5\u00C9d\u00D2\u00E9tb\u00C1\u00CA\x04\r\x06\u0083$\u00B8\u00DDn\u00B1`e\x06\u00CA|>\u00FFt\u00EF\u00EF\u00F7{\u00D4s>\u009F\u0095\fj\u00B5Z\u00F3\u00F9\u00FC}\u00AE%\u00CAG\u00D86\u009BM\u00E0\u00DDn\u00F7\u0087\r\u00B8n\u00B7\u00DB\u0095J\x05\u0091!\u0092\u00D5jE;\u00D1\b\u00D3\u00E9t4\x1A1\x01\u00C0\x12\u0099.\u0097K\u00BC\x1D\x0E\x07\x16|'#\x1A\u00BF\\.\x1F\x0E\x07\u00DCf\u00B3Y<\x1EO$\x12\x14!\x11\x14\u00BE\u0086\u00C3!\u00B3\x07{\u009F;\u009DNG\b\u00CE\x06\u0097J%l\u00A7\u00D3\u00A1M\u00AF\u00CA/\x14\n\u00B7\x1A\f\u00EF\u00FFA\u00C7\u00E3\u00F1b\u00B1 S\u0086@\u00BF\u00DF7\x18\fB\u00E6j\u00B9\u00FF}rG\x00\u0090\x03\u00A7\x1E\u008F\x07B\u00B9:qo\u00D0-\u00B0\u00EC\u00D1\u00C77D\x04\u00D8\u00EDv\u00A3\u00D1(\u00B0X\u00BF\u00F8\u00F9\u00C9\x1F\u008B\u00C5>\u00FA7\u00BD\b0\x00\x06\u00D4\u00AE}\u00FDl\u00C3\x15\x00\x00\x00\x00IEND\u00AEB`\u0082",
    textFrame: "\u0089PNG\r\n\x1A\n\x00\x00\x00\rIHDR\x00\x00\x00\x1F\x00\x00\x00\x1F\b\x02\x00\x00\x00\u0090\u00CC\u0081n\x00\x00\x00\x19tEXtSoftware\x00Adobe ImageReadyq\u00C9e<\x00\x00\x01GIDATx\u00DA\u00ECV=\u008B\u0083@\x10\u008Dz\u00C6N\u00D0B\x1B\u008B\u0080V\u00A2\u00A0\u008D\u0082\x7F\u00C6\u00CE\x1Fe\u00A7?&\x10\bX(V\n\x16V\"\x16v\"\u00E8\r\u00B7\u00DC!\u00A2\u009B\\nS\u00E4\u00EE^\u00B1\u00CC0\u00CB\u00F3\u00ED\u00BC\u00FD\u0090\u008A\u00E3\u00F8\u00F04\u00D0\u0087g\u00E2\u0095\u00D9\u00DF\u00EE\u009Cg\u009A\u00E6\u00E9tBqUUi\u009A\u0092\u00D4\u009EeY\u00DB\u00B6\x10\u00C0\b1\u00E1\u00CE\u00CC\u00F3|\u00BD^\u009B\u00A6\u0081\x11b\u00C2\u009D\x01\u008C\u00E3x\u00B9\\^\u00C4\u00D50\fQ\x10\x04\u00C1\u00CD\u00F4\x11\u00EDQ\x14!\"\u00C4\u00B5\u0099>\u00DE\x19\u00DF\u00F7\u0091:$p3\u00C5\u0080\u00C2\u00DF3\u00A0\x11\u00B3p|u\u00AD]\u00D34\u0096e\x7Fb\u00A3\u00AE\u00EB\u00BB\u00EC\u00A2(z\u009E\u00C7q\u00DC\u00D2\u00D5/\u00F7\u00C2OlVi\u009A\u00B6m[UU\\\u00DFy\u009E\u0087I+W\u0097{c\u00D9\u008Ae\x15\u00D6\u00AD(\u00CA\rW\u00FB\u00BEO\u0092d\u00E5*\u00DEs\u0084\u00A2(\u00EA\u00BA\u00C6\u00B1w]w>\u009F\u0087a\u00D8\x13\u00BB\u00C4\u00AA:M\x13\u00C8*\u00CBr\u00F74\u00C1\u00F7\u00F1\u00A6\u00E1w\b \u00CF\u00F3{\u00F7\u00FB\u00B7\\\u00FDkg\u00F5\u00B7\u00BC\u00DApI\u00B8\u00AE{<\x1E\u00C9\u00B3S\x14\x05gX\u0092$\u00C7q\x18\u0086!\u00CCn\x18\u0086,\u00CB\x10\b\u0082`Y\x16\u00E1w5\u00FD\u00C0\u00FF\u009F\x1E)\u00BC\x0B0\x00\u00EA=\u00B6\u00BC>\u00EF4\u00D9\x00\x00\x00\x00IEND\u00AEB`\u0082",
    flipMargins: "\u0089PNG\r\n\x1A\n\x00\x00\x00\rIHDR\x00\x00\x00\x1F\x00\x00\x00\x1F\b\x02\x00\x00\x00\u0090\u00CC\u0081n\x00\x00\x00\x19tEXtSoftware\x00Adobe ImageReadyq\u00C9e<\x00\x00\x00\u00DDIDATx\u00DA\u00ECV\u00C1\t\u00C4 \x10L\x0E%\u00BF<,A\u00D2\u0080_{H?\u0096\u0090:l\u00C1\x1E\u00FC\u00DA\u0080\u00A4\u0084<\u00F2\x13?\u00B7p \u00C1#K\x0E\u0094\x04\u00CE}MFg2\u0084]c\u00AF\u00B5\u00EE\u00AA\u00D5\u00AB\u00ABY\u00CD\u00BD\u008C\u00FB<\u00CF\x15\u00DD\u008D1\x7F\u0093\u009D$\u00C49\u00FF^^\u00D75\u00CB\u009E\u00BD\x00W\u0091#\u00AB\u0094:>.\u00CBr%;\u00A2\"\u00D9\u00D6\u00B4\u0096i\u00CE\u00B2\u00E3\u00AA\x07\u00F4\f\u00A5t\u009A\u00A6\u00D43\u0080\u0081)\u00E3>\f\u0083\u0094\u00921\u0096\u00B2\x03\x06\x06\u00F8\x02\u00EEB\u0088q\x1C\u00B3~\x07\x06\u00F8\x02\u00EE\u00CE\u00B9}\u00DF\u00B3\u00EF\x0E\f\u00F0\x05\u00DCC\b\u00D6\u00DAm\u00DBRv\u00C0\u00C0\x00\u00FF\u00C34!\x15c\u00F4\u00DE\u00A7\u00EC\x1F|\u00FF9C\u00F0\u00C1\u00BB\u00D8\u00EFg*\u0082\u008F\u00FE\u0095YET\u00FD\u0083\u00EE\x04\u00ED\u00DFtO\u00F6v[*Uo\x01\x06\x00\u00D1DhV8\x1B\x01\u009A\x00\x00\x00\x00IEND\u00AEB`\u0082",
    setMargins: "\u0089PNG\r\n\x1A\n\x00\x00\x00\rIHDR\x00\x00\x00\x17\x00\x00\x00\x17\b\x06\x00\x00\x00\u00E0*\u00D4\u00A0\x00\x00\x00\x19tEXtSoftware\x00Adobe ImageReadyq\u00C9e<\x00\x00\x01\u009BIDATx\u00DA\u00AC\u0095\u00B1\u008A\u00C2@\x10\u0086g\u00F7\u00A2D\x10\u00D2\u00D8\u00A4\n\b\u00B1\x11\u00AC-\u00EFA\u0084<A\u009E!\x1E>IDR\u00F9\x10\u00D7\u0084k\u00AC\x04!\u00D8\t\x076\"\u00D8$\u00A2Bng\u00CF\u0095e\u0089fM2`\u0092]\u00F5\u00FF\u00F6\u009F\u00D9\u009D\x10\x00\x18\u00FB\u00BE\u00FF3\x18\f\u00C0\u00B2,h2>\u00D8\u00E7\u00D7u]\u0092\u00A6\u00E9g\u00B7\u00DB\x05\u00D34\x1B\x15\u0087\u00D1h\u00F4\u009DeY\u00E3\x00\x03/\u00EDv\x1B.\u0097\u00CB\u00F4x<\u00C2v\u00BB\r&\u0093\t\u00F4z\u00BDJ\u0082q\x1C?\u009E)^\x1C\u00C7\u00E1\x00\x16\b\u00F8Z\u00ADVp8\x1C\u009AYy\u00BF\u00DF\u00E7\u0083\u00DDn\u00C7\x1D\u00EC\u00F7{`\u0080`>\u009FC\u00AB\u00D5\u00D2\x12\n\u00C3\u00B0X\\\x05\u00A0\x03\x04\u009CN\u00A7\x00\u00FF$R\u00E4y\x1E\x17\x11w\x118.\n*\x0F\x10\u0080)\u00BA\x17t\u00CA\\\u00D4J\x11U'\x100\x1C\x0E\x1F\x00\u00E6\u00A02\u00C0(\u009Ad[\u00F3\u009FL\u00E9#EX\u0083\u00EB\u00F5Zo\u00E52@\u00DA\u00F3\u00DC\x01\u00AB\u00C1[\x0E\u00E8\u00AB/Q\\N\u0091\u00A8\u0081\u00AE\x03Z\u00F6\x03t\u00A0\u00D6@\u00D7\x01\u00D5Y\u0081\x00\u0088\x1A\u00E8\u00EE\"\u00AA\u009B?\x04`\u00D7D\x07\f\u00A2\u00B5\u008B\u008C2Q\u00F9\u0080t:\x1DX.\u0097\u00FC9\u008A\u00A2\u00E9\u00BD/\x05\u00CFZ\u00B5\u00F1\u00EE\u0091\u00C6X\u00AF\u00D7\u00B0\u00D9l\u00E0|>s\u0080m\u00DB\x01:P\u009B\x1D\u00ADr\u00F2\u00E4\"\u00CFf\u00B3\u00A7)2\u00CA\u00DA\u00E6\u00AB\u00B8\u00DDn\u00FC\u008E\x00l\u00D3I\u0092\x04\u00F2\x1B\u008D\u00D6i\u00A9\u00A2\u00D9a,\x16\x0B\u00DE\u00AE\u00D9\u00FB\x00\x1B^}q5T@\u00A3\u00E2*\u0080\u00D4\x15\u00CB\u00F3\u00BCp\u009E\x102\u00FE\x13`\x00\u00CD\u00C3\u00E6M6\u00FC\u00A1j\x00\x00\x00\x00IEND\u00AEB`\u0082",
    autoMargins: "\u0089PNG\r\n\x1A\n\x00\x00\x00\rIHDR\x00\x00\x00\x17\x00\x00\x00\x17\b\x06\x00\x00\x00\u00E0*\u00D4\u00A0\x00\x00\x00\x19tEXtSoftware\x00Adobe ImageReadyq\u00C9e<\x00\x00\x01\u00BCIDATx\u00DA\u00AC\u0095\u00B1\u00AA\u00C20\x14\u0086Or\u00AF\u00E2 H}\x01AhG\x17\u00C1U_\u00A1\u009B\u00B8\u00B8\u00B9\u0088\u008B/\u00A0>\u0084\u008B[\u00A5p}\x017\x07\x07A\x10\u00DA.wr\x10|\x01A\x10\x05E\u00BC=\u0081\u00846\u00A6\u00DA[\u00FBCZ\b\u00E1|\u00C9\u00FF\u009F\u00B4\x04\x00\u009A\u00BD^\u00EF\u00C70\f(\x14\n\u0090\u00A6\u00BE\u00FC\u00F1\u00AB\u00EB:9\u009F\u00CF\u008D|>\x0F\u00B9\\.\u00D5\u00E2P\u00A9T\u0096\u0097\u00CB%u\u00C07>\u00B2\u00D9,\\\u00AF\u00D7\u00E1\u00E1p\u0080\u00EDv;\u00E0\x16M&\x13\u00B1\u00B0\u00D3\u00E9\u00B0w\u00DC9\x14\u00C5G\u00A9Tb\x00_\b\x18\u00F9\x008\x1E\u008Fl\u0081eY\u00A2\x00/\u00F2j.(\u0082\u008F\u00E9t\n\u00BB\u00DD\x0E\u00F6\u00FB=\u009E\u0080A\u008A\u00C5\u00E2`\u00B3\u00D9@&\u0093I\u00BCsQ\x1C\x15\x05\u00E8v\u00BBo\u00FDE@\u00B0\u00B0\u00B0\u0085\u00AB\\.?Y\u0084\u00F6p\u008B\x12u\u008Bi\u009AbB\u00D34x<\x1Ep:\u009D`\u00B5Z-\u00EF\u00F7;q]\u00B7\u00E1w\x14\u00EB\"\u00DC\u00A1\u00E38lT\u00AB\u00D5\u0090-\u00C1\u00B9\u00A7\u009D\u00CB'\u00A0\u0094B\u00AB\u00D5\x1A\u00FA6\u0089\u0090\u00F9\u00D1e\x0BT\u0081\u00D2\u00A8#!\x00{~6\u009B)\u00BBHV\u00BB\u00DD\u008E_\x1C\u00D5\u00EF\u00F7\x19\u00A0^\u00AF\u0087\x00\u00B7\u00DB-\u00B4.\u00EA4\u00F4](X\\\x0E\u00B9V\u00AB\u00C5\n\u0099\u00BEk/\u00D4b\u00B1\x10\u0080\u00F5z=\u009C\u00CF\u00E7\u00A3\u00F1x,\x00|]\u00B0\u00DFc\u00ED\u009C\x07\u0085\x00\u00CF\u00F3B!#\x00\u00C7\u00BF\x03\u0095\u0083B?y\x06<d\u00BF\u00ED\u0098E\u0098\u0081*\u00D0\u00D0\r\u008D+\u00D5MV\u00FD\x0Fh\u0092\u009B\x17\u00BC\u00C9\u00B6mG\u00B6)M\u00FA\u00AD\u00E6\x00T\x14\u0080~\u00F23@\x00\u0097\n@!E\u00C9\u0080T\u008B\u00CB\x00\u00F2i1\u00FC\u0082\u00AAD\bi\u00FE\t0\x00{\u00D0,\u00FF\u00E6=\u00DA\u00F6\x00\x00\x00\x00IEND\u00AEB`\u0082",
    rulerUnitsBg: "\u0089PNG\r\n\x1A\n\x00\x00\x00\rIHDR\x00\x00\x00\x1F\x00\x00\x00\x14\b\x02\x00\x00\x00\u00FA\x0Bq\u00AD\x00\x00\x00\x19tEXtSoftware\x00Adobe ImageReadyq\u00C9e<\x00\x00\x00&IDATx\u00DAb\\\u00B4h\x11\x03\u00CD\x00\x13\x03-\u00C1\u00A8\u00E9\u00A3\u00A6\u008F\u009A>j\u00FA\u00A8\u00E9\u00A3\u00A6\x0F6\u00D3\x01\x02\f\x00\u0088N\x02\x0E,\n\x13\u0084\x00\x00\x00\x00IEND\u00AEB`\u0082",
    info: "\u0089PNG\r\n\x1A\n\x00\x00\x00\rIHDR\x00\x00\x00\x16\x00\x00\x00\x16\b\x06\x00\x00\x00\u00C4\u00B4l;\x00\x00\x00\x19tEXtSoftware\x00Adobe ImageReadyq\u00C9e<\x00\x00\x02\rIDATx\u00DA\u0094\u0095=K\u0082Q\x14\u0080\u008F\u00FA\"\x05B\u00A6\u00A0\x16*!\x0E\x0ER!\u00D8\u00D4\u00A2\u0083\x194X\u009B\u00FD\u008AZ*h.\u0088\u0086\u00DA\x1A\x05\u0087\u00DCZ+\u00B7h\u00D1Z\u00B4D\f\u00C5\x02\u0095hQS\u00C1/\u0094\u00CE\u00B1\u00AB\u00A8\u00BC_\x1Ex\u00F0\u00E3\u009E\u00F3x\u00DF\u00EB\u00BD\u00E7*\u00C2\u00E10\b\u00C4\"\x12D\u00B6\u0091U\u00C4\u0084t\u0090\"\u0092C\u00EE\u0091\bR\u00E1+\u00E6x\u00BE\u009BC\x0E\u0091#D;5\u00A6F\x1C\u008C\x1D\u00E4\f\u00B9D\u00AE\u0090\u00E6x\u00A2r\u00AAp\x05yE\u00CEy\u00A4|\u00A1e\u00F2\x17V\u00CB+6#\u00CF\u0088\x13f\x0F'\u00AB5O\u008B\u00E9\u00F1\u00EF\u00C6\x07\u00F8\"\u009F\u00CFC(\x14\u0082X,\u00C67lf\u008E\u00F9q\u00F1\x01\u00E2\u0096\u009AV&\u0093\u0081n\u00B7\x0B\u00E9tZ(\u00C5\u00CD\\\x03\u00B1\x0E9\u0091\u00F3\u00BC6\u009Bm\u00E2U \u008E\u00C9\u00C9\u00B1-\u00B5 G\u00ECp8\u00C0n\u00B7\x03\u00C7qbi\u00E4\n\u00D2\u008C\u00B7f\u00F9\u0097$\u00A4\u00C3\u00F0S\u00D6\u00BATV\u00ADV\u0083D\"\x01\u00EDv\x1B\\.\x17\u00E8\u00F5z\u00A9\u00925\x12\x1B\u00C52*\u0095\nD\u00A3Q\u00A8\u00D7\u00EB\u00D0\u00EF\u00F7\u00A1\u00D7\u00EB\u0081\u00DF\u00EF\u0097\x12\x1Bi)\u00DAb\x19\u00F1x\x1C<\x1E\x0F(\x14\u008A\u00FF\u00A3\u00A7V\u00CBZ2\x12\x7F\u008B%x\u00BD\u00DE\u00C1\x16\u00A3\u0099R\u0098L&9\u00DE\x1F\x12\x7F\u0088e\u00D0\f\u008B\u00C5\u00E2\u00E8\u00B3\u00D5j\u0095#N\u0092\u00F8Q*\u00ABP(\f^u:\x1Dh4\x1A9\u00E2\x07%k}\u00BFB\x19\u00ADV\x0B\u00CA\u00E5\u00F2\u00E0\u00BD\u00C5b\u0081l6\x0B\u00A5RILJ\u00AE\b\u0089\u00A9\u00EAB(\u00AB\u00D1hLl\u00BBd2\tF\u00A3\u00E8F\"Wy\u00D8+\u00AE\u0091w\u00DE\u00BE\u00A8\u00D5\u0082\u00C1`\x00\u0095J\x05\u009DN\x07|>\u009F\u00D8!I1\u00D7\u00A8\u00D1S\u0093\u00DEC\u009E\u0090\u00E5\u00E9\u0093\x16\b\x04\u00E4\u00AC+\u00AD\u00CF\u00EE\u00B0\u00E1\u008F\u00F7c\u00BAn6\u00D9\u00AF\u00CE\x1A)V\u009B\x13\u00BAA>\u0091\r\u00E4\x14\u00A9\u00CA\x10VY.\u00D5|I\u00DDyMv5\u00DD \u00FB\u00D4P\u00D8e\u00BA\u00C4\u00C6\u00E9@\u00BD\u00D1\u0096Bn\u0085.\u00D3?\x01\x06\x00\u00F3\u00E5\u008B\u00B8\u00CB\x10\u008A[\x00\x00\x00\x00IEND\u00AEB`\u0082",
    lightBlue: "\u0089PNG\r\n\x1A\n\x00\x00\x00\rIHDR\x00\x00\x00\n\x00\x00\x00\n\b\x02\x00\x00\x00\x02PX\u00EA\x00\x00\x00\x19tEXtSoftware\x00Adobe ImageReadyq\u00C9e<\x00\x00\x00PIDATx\u00DAl\u008FQ\x0E\u00C0 \bC)\u00E1\u00FE\x17\u00D8a\u00BBM\rV\u0090\x0F\x02\u00BCB\x03\u00EC\u00A1\u00D1.\u0081?\u00F9bh\u0098\x13\x17\u0086C\x1D)\\S\u008A\u009A\u00DF\u00B6\u00CAY]|;a[f\x1B\x15\u00E4\u00FD\u0091\u00BD>\u00C3\u00EBqyF\u008B\u00E8\x1B\u00EA\u00F5\n0\x00]\u008F\x14\u00B46([\x1B\x00\x00\x00\x00IEND\u00AEB`\u0082",
    red: "\u0089PNG\r\n\x1A\n\x00\x00\x00\rIHDR\x00\x00\x00\n\x00\x00\x00\n\b\x02\x00\x00\x00\x02PX\u00EA\x00\x00\x00\x19tEXtSoftware\x00Adobe ImageReadyq\u00C9e<\x00\x00\x00:IDATx\u00DAb\u00FC\u00EF\u00C5\x00\x02\u008C\f(\u00E0?T\u0084\tD1\u00C2\u00840\x00\x13\u0082\u0089l\x00#\u00A64\x03~\u00DD\u00D8\u00A51\u00AD\u00FC\u008F,\u008D\u00C3\u00CD8\fg$\u00CDn\u00BC\x00 \u00C0\x00T'\x06a\u00E1K\u00C1\u00FA\x00\x00\x00\x00IEND\u00AEB`\u0082",
    green: "\u0089PNG\r\n\x1A\n\x00\x00\x00\rIHDR\x00\x00\x00\n\x00\x00\x00\n\b\x02\x00\x00\x00\x02PX\u00EA\x00\x00\x00\x19tEXtSoftware\x00Adobe ImageReadyq\u00C9e<\x00\x00\x00dIDATx\u00DAT\u008F\u00D1\r\x00!\bC)q\u00BD\u00DB\x7F\u0092\u00FB\u00AE\x02\x02\u0082\u0089!\u00FAZ\n\u00E4\u00FFD(V\u00F0\u009B\u00DE0Z\u00ED?\u00DE\u00A7Dq\u00CEJ\u0096W\n\x14rJ\x1FE\x16\u008B\u00C7js\u00C8c 6\u008B\u00D4G\u0092\u00B9\"\x04L\u00A0\x1D\u00B9\x18\u00F4\n\u00EA\u00F8\u009CL\u0096\u008D/\u0086\u00A1\u00CD\u009B\u0099|\x18\x04\u00EDj`\x0B0\x00\u0094\u00C4*Q\x0BM=/\x00\x00\x00\x00IEND\u00AEB`\u0082",
    blue: "\u0089PNG\r\n\x1A\n\x00\x00\x00\rIHDR\x00\x00\x00\n\x00\x00\x00\n\b\x02\x00\x00\x00\x02PX\u00EA\x00\x00\x00\x19tEXtSoftware\x00Adobe ImageReadyq\u00C9e<\x00\x00\x00SIDATx\u00DAdP\x01\x0E\x00!\b\x02\u00D7w\u00EE\u00FF\u00CF\u00E3\u00BC\u00BA\x19\x19k\u00CE\x02\u0091E<B![\u00C21P,\u00E71q^\u00C7\u00E6\u00EC\u00B5\x10h\u00E8\u00E6\u00EC\u0082?\u0081\x16}\u0083\u00BB\u00C6\u00A7\u0092\u00CD\u00E1\u00E8/s\x1D\t\u00A2\u008F\u00D2\u00CC\u0095\u00F4JQ\x1FR\u00BBf}\x05\x18\x00\u00F5H\x13J\u00D4\u00FB\u00C3\x03\x00\x00\x00\x00IEND\u00AEB`\u0082",
    yellow: "\u0089PNG\r\n\x1A\n\x00\x00\x00\rIHDR\x00\x00\x00\n\x00\x00\x00\n\b\x02\x00\x00\x00\x02PX\u00EA\x00\x00\x00\x19tEXtSoftware\x00Adobe ImageReadyq\u00C9e<\x00\x00\x00YIDATx\u00DAl\u008FQ\x0E\u00800\fB\u00A1\u00F1d\u00DE\u00FFH&8\u009B\u00D6Q#_o\u0094\u00D1\u008D\u00BAN,\x11\x10\n\u0090\u009CN\x00v~\u00B9\u009D\x1E\u00BB\u00BB\u00C5c4\u00C3:\x16I\u00B1]\u00CE\u00DBz(\u00CA\u0092\x0F2\u009Ei\u00DBM[\u00AA\u00CA\x06>\u00E2\u00A0\u00F8\u009F\u00B1\n\u00EC\u00E5\u00FE\u00A5\u00E6[\u0080\x01\x00\u00B7\u00F6\x1BO\u00AFE\x0E?\x00\x00\x00\x00IEND\u00AEB`\u0082",
    magenta: "\u0089PNG\r\n\x1A\n\x00\x00\x00\rIHDR\x00\x00\x00\n\x00\x00\x00\n\b\x02\x00\x00\x00\x02PX\u00EA\x00\x00\x00\x19tEXtSoftware\x00Adobe ImageReadyq\u00C9e<\x00\x00\x00EIDATx\u00DAt\u008F\u00C1\x0E\x00 \bB\u00C1?\u00EE\u00FF\x0F\u00B4f\u00B6\u0099\u00EAM\x1EC\u00A4\u00960\u008Fa\u00A2r\u00CC_\u00BA\u00C3\u00B3Zb\u00AC\u00E1\u0095)b\u00F80Cr\x1Fk5f\x1Fj5L\u00B7\u0091;7\u00D5\u00D0|\u00B8\x05\x18\x00\u00B4\u00B2\x10\u0081\u0087`!,\x00\x00\x00\x00IEND\u00AEB`\u0082",
    cyan: "\u0089PNG\r\n\x1A\n\x00\x00\x00\rIHDR\x00\x00\x00\n\x00\x00\x00\n\b\x02\x00\x00\x00\x02PX\u00EA\x00\x00\x00\x19tEXtSoftware\x00Adobe ImageReadyq\u00C9e<\x00\x00\x00(IDATx\u00DAbd\u00F8\u00FE\u009F\x017`b\u00C0\x0B\u00E8(\u00FD\x1F\u00BF4#V\u00E9\u00FFX\u00F4A\x00\x0BVM\u00C4:\r \u00C0\x00\u00A2a\x05\x0B\x17\u0092\u00FC\x00\x00\x00\x00\x00IEND\u00AEB`\u0082",
    gray: "\u0089PNG\r\n\x1A\n\x00\x00\x00\rIHDR\x00\x00\x00\n\x00\x00\x00\n\b\x02\x00\x00\x00\x02PX\u00EA\x00\x00\x00\x19tEXtSoftware\x00Adobe ImageReadyq\u00C9e<\x00\x00\x00$IDATx\u00DAbllld\u00C0\r\u0098\x18\u00F0\x02r\u00A5\u00FF\u00FF\u00FF\u008FO\u009A\u0091\u0091\u0091vvSC\x1A \u00C0\x00\x1B\u00CD\x04\u0097[\u0085Z\u00EB\x00\x00\x00\x00IEND\u00AEB`\u0082",
    black: "\u0089PNG\r\n\x1A\n\x00\x00\x00\rIHDR\x00\x00\x00\n\x00\x00\x00\n\b\x02\x00\x00\x00\x02PX\u00EA\x00\x00\x00\x19tEXtSoftware\x00Adobe ImageReadyq\u00C9e<\x00\x00\x00\x10IDATx\u00DAb`\x18\x05\u00A4\x03\u0080\x00\x03\x00\x016\x00\x01\u00BA\u009Af\u00FA\x00\x00\x00\x00IEND\u00AEB`\u0082",
    orange: "\u0089PNG\r\n\x1A\n\x00\x00\x00\rIHDR\x00\x00\x00\n\x00\x00\x00\n\b\x02\x00\x00\x00\x02PX\u00EA\x00\x00\x00\x19tEXtSoftware\x00Adobe ImageReadyq\u00C9e<\x00\x00\x00=IDATx\u00DA\u0084\u008FA\x12\x00 \b\x02\u00A1_\u00F7z\u00BA\u00D4\fj\u00D9^WP\u00A9\u0089\u008D\x00\"1\x1Ag\u009Ag\u00C8\u0091\u00A7Q\n\u0098\u00D2\u00CF\u00F2\u008A\u00AAVh\u008E\u00BA{\f\u00DF\u00DD\u00B7\u00EB\u0096\x00\x03\x00\u00E4+\t\u008D\u0096\x0Fi\u00F3\x00\x00\x00\x00IEND\u00AEB`\u0082",
    darkGreen: "\u0089PNG\r\n\x1A\n\x00\x00\x00\rIHDR\x00\x00\x00\n\x00\x00\x00\n\b\x02\x00\x00\x00\x02PX\u00EA\x00\x00\x00\x19tEXtSoftware\x00Adobe ImageReadyq\u00C9e<\x00\x00\x00EIDATx\u00DAtNA\x0E\x00 \b\x02\u00D7\u00FF\u00FA\u00FFklk6K\u008C\u0083SA\u0084\u0098HpW\u00CF\u0085\u00A1\u00C0\u008F(i~\x15\u00F6\u00B8Ic!\u00A4x\x04\u00AD\u00A7\u00D0h\x1D\u00D7%o\u00E8\u00F2\u00F5\x1AG\u00E3\u00EC)Z\x02\f\x00\u009BV\x0Bd\u00DA\x0BH\u00CC\x00\x00\x00\x00IEND\u00AEB`\u0082",
    teal: "\u0089PNG\r\n\x1A\n\x00\x00\x00\rIHDR\x00\x00\x00\n\x00\x00\x00\n\b\x02\x00\x00\x00\x02PX\u00EA\x00\x00\x00\x19tEXtSoftware\x00Adobe ImageReadyq\u00C9e<\x00\x00\x00cIDATx\u00DAlO[\n\u00C00\bK\u00A4\u00F7\u00FF\u00DB\u00DF\u00EE\u009A\u00A9\u00B3\u00B5e\u0093B!\u00E6%q\u00DD\u00F0! \u0081\u0084\u00D0CX\u00FE;\u0086\u0089\x04h\u00BDsiS\x19O\u00A5f8k#\u00E56\u00D5%b[\u00F2\u009B]tm\u00B9Qv\u00FC\x14^\u0087\u0080\u00F6V8;\u00CF\x12e\u00DE\u00E9\u00EC\u00E4\u00A4\u008DC\u00B6J\u00A5\u00B3#\u008F\x00\x03\x00\u00BC\x0F!K\u00B0s\u00A6\u00CF\x00\x00\x00\x00IEND\u00AEB`\u0082",
    tan: "\u0089PNG\r\n\x1A\n\x00\x00\x00\rIHDR\x00\x00\x00\n\x00\x00\x00\n\b\x02\x00\x00\x00\x02PX\u00EA\x00\x00\x00\x19tEXtSoftware\x00Adobe ImageReadyq\u00C9e<\x00\x00\x00mIDATx\u00DALO\t\x0E\u00C0 \b\u00A3\u0086\u0097\u00EE_{\u00DD\x1E\u00D2\u0081\x05\x14\x13#\u00B1'\u00BE\u00F71X\x0E\u00ED\f`d\u00DC^\u00AB\u0081\x10\x04\x05D\u00EEK\u00BC8(\"[&\x1E\\\u00A3,\u00CA\x162\u00B4\u00D7\x1A3\u00D8\u00F9\u009F\x18>p\u008E\u00C7\u0095Q\u00D12\u00E5\u008EU\u0081\x07\u00E3U\u00A9\u00F4(\x04\u00BB\u00CF\x12\u00FCn\u00A4J\u00F2\u00F4\u00CA\t\u00A43\u00BA\u00C3F\u0084\u00CA/\u00C0\x00O<0\x06\u009E{P;\x00\x00\x00\x00IEND\u00AEB`\u0082",
    brown: "\u0089PNG\r\n\x1A\n\x00\x00\x00\rIHDR\x00\x00\x00\n\x00\x00\x00\n\b\x02\x00\x00\x00\x02PX\u00EA\x00\x00\x00\x19tEXtSoftware\x00Adobe ImageReadyq\u00C9e<\x00\x00\x00QIDATx\u00DAlO\x01\n\x001\b\u00D2\u00D8\u00BF\u00F6\u00ED\u00FB]w\u0083:%&!dS\x1C\u009F\u008D\u0083\x04h\u00DCX\u00B5\u00D0\u00F8\x07\x11\u0092Rj\r\u00BE\u00F3\u00D5\u009A\u00C5!S\u00F6@mV\u0099<\u00D9\u0092\u00A2\x1C\u009C\u00B1\u00DD|\u00B4\u00C5\u00D5=\x0E-v\u00F3\u00D4g\u00FC\u00D1+\u00C0\x00\u00BE\x0F\x18\x11J\u009D@\x00\x00\x00\x00\x00IEND\u00AEB`\u0082",
    violet: "\u0089PNG\r\n\x1A\n\x00\x00\x00\rIHDR\x00\x00\x00\n\x00\x00\x00\n\b\x02\x00\x00\x00\x02PX\u00EA\x00\x00\x00\x19tEXtSoftware\x00Adobe ImageReadyq\u00C9e<\x00\x00\x00\\IDATx\u00DAT\u008F\x01\x0E\u00C0 \b\x03)\u00E1}{\u00EB~X1L\u00D7\u0092\x18\u00E0\u0084V\u00F1>\u008C\u0089\u00C9\u00B0\u00BA\"\u00EC\u00B6\x13\x04\u00D5\u00C1BOCF*fX\x00\u0091\x14K\u00CC\u00C1\x19\u00E4\u00F5\u00BEC4\u00A9\u00FC\b\u00C4U\u00EA\u00ED\r\u00D8\x06\u00E5\t\u00D9h\u00F7\u00A2\t\u00F9d\u00FD\u00C2\u00B0\x7F\u00F5N\u00AB.\x01\x06\x00UY\x1F\x17\u00B4\u00CE\u00FE\u00D3\x00\x00\x00\x00IEND\u00AEB`\u0082",
    gold: "\u0089PNG\r\n\x1A\n\x00\x00\x00\rIHDR\x00\x00\x00\n\x00\x00\x00\n\b\x02\x00\x00\x00\x02PX\u00EA\x00\x00\x00\x19tEXtSoftware\x00Adobe ImageReadyq\u00C9e<\x00\x00\x00PIDATx\u00DAl\u008EK\x0E\x00!\fB)\u00F1\u00FE\u0097\u0098\u0083b\u00D4\u00D1~\u0094\x05i\u0093\x07\u00AD\u00E9\u00C3\u0090\x00{8\u00B1d\u00DB3\u00C11a\x17\\\x1C\u00FF]\u00C1\u00F1L\u009F\u00A8|\u00A5\u00B7\x19\x12:\u00C5\u0082'\t\u00CD_-\u0084V\u00BAt\n\u00F1\\\u00BB\x13\u00F1\u00FF.\u00C0\x00\u00AE\\\x1C\u00B9\x11\u00D1\n8\x00\x00\x00\x00IEND\u00AEB`\u0082",
    darkBlue: "\u0089PNG\r\n\x1A\n\x00\x00\x00\rIHDR\x00\x00\x00\n\x00\x00\x00\n\b\x02\x00\x00\x00\x02PX\u00EA\x00\x00\x00\x19tEXtSoftware\x00Adobe ImageReadyq\u00C9e<\x00\x00\x00gIDATx\u00DA\\\u008F\x01\x0E\u00C0 \b\x03)\u00F1\x05\u00FB\u00F5^]\u0085\u00E2\u00D0iB\u0080\x1E\x15a\u00CFk\u0080\u0091\x11\u00AF\u00C3u\u00BD\u00F2\u00D6\u0098!\u00B4\u00D5t\u0083\nnYN\u0085\u00BA\u00E8\u009E.\r\u008A~=\u00F9m\x10f\u0091\u008C\u00C2e^(r/\u00A6\u00AC\x16\x0E\x03q\u00E94.\u00E7\u0093K\u00C2\u00FB3\u00AB\u008E\u00D6Fr\u00DAk\u008B\u0088\u00FC\u00DB\u0090S\u0080\x01\x00\u0092\u00CB2\u00B0\u0099\u0096K\u00B4\x00\x00\x00\x00IEND\u00AEB`\u0082",
    pink: "\u0089PNG\r\n\x1A\n\x00\x00\x00\rIHDR\x00\x00\x00\n\x00\x00\x00\n\b\x02\x00\x00\x00\x02PX\u00EA\x00\x00\x00\x19tEXtSoftware\x00Adobe ImageReadyq\u00C9e<\x00\x00\x00eIDATx\u00DATO\t\x0E\u00800\b\u00A3\u00C4\u00FF\u00FF\u00C2\u00DF\u00F8'\u00B4P\x18\u0092e\x19\u00BD`\u0088\u00FB1\u0098\u0085\u00B1\x00\u008B\u00E0\u00CD\"\u00E4j\u0084\x14\x17<ipB\u00C5\u008F\u00A2^L\u00A2\u00DB\x14U8\u00B6\u00E2\u00A35E*-\u00D1u)g\u00B8\x7F\u0098w\u0093K\u00E5\u00BCIn\u00B7\x02&\u00F7\fp\u00CAb\u00E5\u00F6\u00BF\u0086.|\u00B91f\u00BC\x02\f\x00\x7F\u008D$\u008E\x1A\u008C\u0089\u0080\x00\x00\x00\x00IEND\u00AEB`\u0082",
    lavender: "\u0089PNG\r\n\x1A\n\x00\x00\x00\rIHDR\x00\x00\x00\n\x00\x00\x00\n\b\x02\x00\x00\x00\x02PX\u00EA\x00\x00\x00\x19tEXtSoftware\x00Adobe ImageReadyq\u00C9e<\x00\x00\x00ZIDATx\u00DAd\u008DK\x12\u00C0 \fB!\u00E3\u00FDW]\u00F7\u00AA\u00A8\u0093\u008F\u00B1\u00CD\u00C2\u00C0\u0084\u0087|^\u0081\u00D0~\u00AE\x11@b\u00EC\u00A5\u00F0}Vz1V\u00C1\u00A2]{\u00DA*(d\u00E2(\f6\u00AB\u00BB<\u00E8\u00CED\u00AD\u00EEr\u00FC\u00B8/\u00ED\u009C\u00D2\u00B86e\u00B3\x1A$\u00856\u00B6\u00C3\u00D1\u00F9\u00C1\x14`\x00(}!K\u00DC*\u0093v\x00\x00\x00\x00IEND\u00AEB`\u0082",
    brickRed: "\u0089PNG\r\n\x1A\n\x00\x00\x00\rIHDR\x00\x00\x00\n\x00\x00\x00\n\b\x02\x00\x00\x00\x02PX\u00EA\x00\x00\x00\x19tEXtSoftware\x00Adobe ImageReadyq\u00C9e<\x00\x00\x00gIDATx\u00DALO\u00C9\x11\u0080@\bK\x18\u009B\u00B1\u00FF\u009F\u00CDE!\u00E0\u00C2c\u0097\u00C9\x05\u00F0\u00B9AB\u00C8\"\u00B2\u00C9\u00D7\x1Fp\u00C1\\\u00F1*\u00E8\u00E3XM\u00D1\x18\u00E3\u00F2\u00A9Q\x04m\x1D\u00805\u0080\u00D6\x0B!\x1D\u00D4\u00CA\\E\x1D\x13\u00E4I\u00D3\u00BF\u00DD\u00CC\x0E\u00EC\u00D2\u00EA\u00B9\u00C3\x07\u00D2b\u00D9\u00E1\u00EB\x18\u00EB<\u00FB\u0093\u0086\u008F\u00F6:\u00AD;ix\x05\x18\x005)-\u00F9\u00E8\u00FF\u00B7\u00D9\x00\x00\x00\x00IEND\u00AEB`\u0082",
    oliveGreen: "\u0089PNG\r\n\x1A\n\x00\x00\x00\rIHDR\x00\x00\x00\n\x00\x00\x00\n\b\x02\x00\x00\x00\x02PX\u00EA\x00\x00\x00\x19tEXtSoftware\x00Adobe ImageReadyq\u00C9e<\x00\x00\x00\\IDATx\u00DA\\P[\x0E\u00C0 \bk\tW]\u00B2\u00FB_\x00'\u00B3\n\u00F2\u00A1M\x1F\u0080\u00F2}\u00B0\u008B@\u00E4\u0089\x04_9\u00A5\u0085\u00A88~XH z\u00A5\u00CBj\u00BA\x05\u00A94%\u0090\u009B_\u00C0\u0096\u00C4\u00ABk\u0082\u0080\u00A3\u00AFZ\x1A\u00CF\u00CB\u00CFTN\u00FB\u00CFn\u00AB5?\u00F5\u00F6k\u00F3\u00AA\u00D6\u00DF\x19\x02\f\x00\u009AH\x1A\u00E7\u00AA\u0098\u00A2_\x00\x00\x00\x00IEND\u00AEB`\u0082",
    peach: "\u0089PNG\r\n\x1A\n\x00\x00\x00\rIHDR\x00\x00\x00\n\x00\x00\x00\n\b\x02\x00\x00\x00\x02PX\u00EA\x00\x00\x00\x19tEXtSoftware\x00Adobe ImageReadyq\u00C9e<\x00\x00\x00aIDATx\u00DATOA\x0E\u00C00\bB\u00D3\u00FF\u009F\u00F7\u0080\u00FD\u00D3M\x11cM\x0FP\x05\u00D1\u00E2}\u0080\x00\fY\x02b\u008E)[\u00DF\x11\x04\u009E\u00C4L#QO\x10[ME\u008F\x1Ae\u009E|7\u0082f\u00ED\u00E1\u00D5\u00DB\u008D+\u00CB\u00D99\u00DBF\u00B9\u0098\\\u00E6?\x18u\u0082\u00A4\u00A7om\x1D\u0087\u00C6\u009B\u00EA\u00AB\u00EAh-\u00FA\x04\x18\x00aY,NT$\u00B5\u00A9\x00\x00\x00\x00IEND\u00AEB`\u0082",
    burgundy: "\u0089PNG\r\n\x1A\n\x00\x00\x00\rIHDR\x00\x00\x00\n\x00\x00\x00\n\b\x02\x00\x00\x00\x02PX\u00EA\x00\x00\x00\x19tEXtSoftware\x00Adobe ImageReadyq\u00C9e<\x00\x00\x00gIDATx\u00DA\\P\u00DB\r\x00!\b\u00A3\u0084i\u00DC\u00FF\u00EB\u0096\u00EB\x01\"\x11}$\u00C5R(\u00E2[K B\x19\x0B\u00B1I\u00EAF\u0091\u00D1\x14\u00E0\u00D9\u00CE9V\u00BF\u0081X\u00A2\nO\r\x0BbK\u00D9e\u0092g\x1CE7F\u00E8\u00D8\u00DA\u00D4\x18\x1FSr\u00D9D\u00F6\u0096S\u00AA|\u00B5\u009A\u00DE\x1BC\u00C4\u00B40\u00AD]\u00E3>\x1F`\u00E3\u00A9\u00A78\u00E1/\u00C0\x00\u00B7c,!\u00C1\u00F1\u00A7\u009D\x00\x00\x00\x00IEND\u00AEB`\u0082",
    grassGreen: "\u0089PNG\r\n\x1A\n\x00\x00\x00\rIHDR\x00\x00\x00\n\x00\x00\x00\n\b\x02\x00\x00\x00\x02PX\u00EA\x00\x00\x00\x19tEXtSoftware\x00Adobe ImageReadyq\u00C9e<\x00\x00\x00[IDATx\u00DAlO\x01\x12\u0080 \b\u00DB8\u00BF\u00DD\u00FF\u00FA\u00D5R\u0088\u0082\u008C;\x05a\u00C3\u008D\u00C7\t\b jH W\u00DF\u00D6l\x0B\x06\u009A\x18\u0091^\x10\u00DB\x0E\u0093'\u00F0;\u008B\x1D6\x0F+\x1BY\u00FB=\u00EEG\u00E51\u00A5aJ\u00DB\u00FE\u00AB\rk<'\u00A9\u00F8\u00EC\u00C6\u0098\u00AE\u00F4\u00CB~t%\u00E2\x12`\x00*\u0083\x1Bb\x0F\x1B\x02\u00A2\x00\x00\x00\x00IEND\u00AEB`\u0082",
    ochre: "\u0089PNG\r\n\x1A\n\x00\x00\x00\rIHDR\x00\x00\x00\n\x00\x00\x00\n\b\x02\x00\x00\x00\x02PX\u00EA\x00\x00\x00\x19tEXtSoftware\x00Adobe ImageReadyq\u00C9e<\x00\x00\x00bIDATx\u00DA\\\u008F\x01\x0E\u00C0 \b\x03)\u00F1\u00B5\u00FB\u00DC\u009EX\x07\x15e\x12M\n\u00A1W\u00C5\u00FB\x18,\u008Ay\u0081\x14\u00A5G\b\r\x10gKi\x0F\x01k\u0084%\u00D5\u00BA\u0086(\u00876>\x1E\u00B3\u00F5\u00C8\u00B0\u00CA\x13\u00A9\u00D5q\u008B\u00C6\u00B4\u00EE%\u00BF\u00A7\u00C5Q\u00DC\u00D8@\u00B6\b^O\u0093\x15-\x1B\x0B\u008E\u00F3)\u00D2\u00EC\x0F\u0098\x02\f\x008\u0080'0@,\u00E6J\x00\x00\x00\x00IEND\u00AEB`\u0082",
    purple: "\u0089PNG\r\n\x1A\n\x00\x00\x00\rIHDR\x00\x00\x00\n\x00\x00\x00\n\b\x02\x00\x00\x00\x02PX\u00EA\x00\x00\x00\x19tEXtSoftware\x00Adobe ImageReadyq\u00C9e<\x00\x00\x00pIDATx\u00DAdO\x01\x12\u0080 \b\u00DB\u00B8\u00BE\u00D1\u00F7zD\u009F_\u00C0\f\u00BBk*\u00A2\u00C0\x06\u00BC\u00CF\u008B\u00A4 $\u0084\u00F2\u0095W/ \u00D2N\u00ACL\u00C7\u008C\u00F4\x03Z\u0089e\u00BC\u00B1\x7F\u00C2\u00CC~\u00A7\u00E5\u008A\u00C9\u0094QlC\u00DD\u00DF\rn\u00ED\\V\u00D4$\u0095n\u00F9\x07^\b\u00AB\u00DF\u00D6\u00F2A8\u00F3\u00AD\u0095[\u0094>\u0083\u00CD\u0094\u008B\u00B6S\u00D4#U\u00B5\x15I\u00E2\u0087G\u0080\x01\x00\x18\u00A9:\x10P\u00E5\u0085\u00F9\x00\x00\x00\x00IEND\u00AEB`\u0082",
    lightGray: "\u0089PNG\r\n\x1A\n\x00\x00\x00\rIHDR\x00\x00\x00\n\x00\x00\x00\n\b\x02\x00\x00\x00\x02PX\u00EA\x00\x00\x00\x19tEXtSoftware\x00Adobe ImageReadyq\u00C9e<\x00\x00\x00VIDATx\u00DA\\\u008EQ\x0E\x00 \bB\u00D3y\u00FF\x13y7\u00B3h\u00C4\u00E4\u00A3\u00B9`\x0F,3\u00D7UU\u0099Y\u00BF}\u00F3\b\x18K\u00D4\x1EoWCs\b\u0085\u00C6a\u0093\u00DFr\x1A\u00E8\x1E\u00F0\u00D0-\\\u00F7\u00A7!\u00CBV\u00F5\u00DE4b\x07\u00F9ts\u008E\x0E$\u00D25\u00AEp\u00FCo\x01\x06\x00H\u00FFJJe|G|\x00\x00\x00\x00IEND\u00AEB`\u0082",
    charcoal: "\u0089PNG\r\n\x1A\n\x00\x00\x00\rIHDR\x00\x00\x00\n\x00\x00\x00\n\b\x02\x00\x00\x00\x02PX\u00EA\x00\x00\x00\x19tEXtSoftware\x00Adobe ImageReadyq\u00C9e<\x00\x00\x00gIDATx\u00DAdO[\x0E\u00800\b\u00A3\x0B\u00F7?\u0086\u00DF\u00FEy\u00BCJ\u0089\u00C0T\u0096\u0094\u00B0\u00B6<p\x1E\u0097mA\x12@\u0097\u008Blb\x14CGY\u00A6\u00AF5\x18W\u00CD1\u00ED\b\u00C3\u00B2\u00CC\u0082\u00F2!#\u00CD\\\u0082\u009A\u0085\u00A4\x1Ek*\\\u00D6^\x05\u00AF\u00EDB\u00ED)\x14\u00C4O\u00AF\u00D5\u0083\u00E20V7\u00FB\u0087C=\u00E6\x12=\u00C3\x03\u00E4-\u00C0\x00\u00F3\u00EE9$\u00E7\u00F8\u0087\u0093\x00\x00\x00\x00IEND\u00AEB`\u0082",
    gridBlue: "\u0089PNG\r\n\x1A\n\x00\x00\x00\rIHDR\x00\x00\x00\n\x00\x00\x00\n\b\x02\x00\x00\x00\x02PX\u00EA\x00\x00\x00\x19tEXtSoftware\x00Adobe ImageReadyq\u00C9e<\x00\x00\x00xIDATx\u00DAL\u008F\u00DB\x15\u00C00\bB!'\x13u\u00FA\u00EE\u00D2a\u00A8\u0082}4\x1F!\u008Ax\u00CB\u00E3\u00BCH\x02P\x1D0\u00F7T\u00A4UJ-\u00C4\u00EE\u00A1\x1D\u00BE\u00ED\u00C6\u0096%l\u00C2h\u00BC\u00C5\u00E5\u0081*\u00B8\u00ABh7{\u008F\x162\u0084_p/&\u00FDX\u00F1\u00E5\x19'\x1F\u00C2*m\u00A3u\u00CE0\x0E\x13\x02\u00E8\u00DD\u00EA\u0084\u0082\x7F\u00D0\u00FA\u008Bi;\u00D8\x7F\u00C9\u008FA\u00D2Lk\u00A6\u009C1R\u00E1\u00AF\u00CE-\u00C0\x00\f\u00D5C\u00D9\x1Dp\u00E3\u00EE\x00\x00\x00\x00IEND\u00AEB`\u0082",
    gridOrange: "\u0089PNG\r\n\x1A\n\x00\x00\x00\rIHDR\x00\x00\x00\n\x00\x00\x00\n\b\x02\x00\x00\x00\x02PX\u00EA\x00\x00\x00\x19tEXtSoftware\x00Adobe ImageReadyq\u00C9e<\x00\x00\x00TIDATx\u00DAt\u008Fa\x1A\u0080 \bC\x1F|]\u00B5[v\u00B7\u0095F\u008A\u00A6\u00FC\x1Al\u0083a\u00BAN\x04F\u00A9\x17\u0088(\u00C3\x03\u00B5Q\u00E2\x1E\u00EC\u00B3\u0095\u00A4+n\u00DBXk{\u00C4h\u00F2\u00FDn+\b\r\x19\u00BD+\u00B7\u00B7\u00F3\u00D2\u00AC\u00A0\u00BB?fL\u00D7\x1E\u00D3\"9\u00DC\x02\f\x00q\x1E\x1D0\u0083jO\x1D\x00\x00\x00\x00IEND\u00AEB`\u0082",
    fiesta: "\u0089PNG\r\n\x1A\n\x00\x00\x00\rIHDR\x00\x00\x00\n\x00\x00\x00\n\b\x02\x00\x00\x00\x02PX\u00EA\x00\x00\x00\x19tEXtSoftware\x00Adobe ImageReadyq\u00C9e<\x00\x00\x00CIDATx\u00DA\u008C\u008EA\n\x00 \f\u00C3Z\x1F\u00EB\u00D5\u00FF\u009F*\u008AL&+8\u00C6.\u0081d\u00D4\u00E8(G\x00\u00D1\u00E0\u0086\u00EBx\u008C\u00C0\u00DAk1\u008F*\u0085Q\u00CAu\u00C3\u00FF\u00ED\u00FCp\u0096\u00BFay\u00F9b\f\u00C1\x14`\x00@'\r\u00E6rz\u0088\u00EE\x00\x00\x00\x00IEND\u00AEB`\u0082",
    lightOlive:  "\u0089PNG\r\n\x1A\n\x00\x00\x00\rIHDR\x00\x00\x00\n\x00\x00\x00\n\b\x02\x00\x00\x00\x02PX\u00EA\x00\x00\x00\x19tEXtSoftware\x00Adobe ImageReadyq\u00C9e<\x00\x00\x00lIDATx\u00DALO\t\x0E\u00C0 \bk\u0089\u00AF\u00DD'\u00F6\u0099\u00FD\u00B3\x13\u00A8D\x12\u00A3Rz\u00C0\u00F7{\x00\u00908EH}CX\u009Cn\u00D7\u00C6XH\u0091\"?\t\u00A9\u00C1\u00C6\u008A\u009F\u00DD\u00B0\u0094\u00FA4\u008F\u00E3\x15\u00E3i>\u00EE9-\u00A7\u00E2\x05\u00A4\u00BD.\u00B6Tn\u0087\u00C4Q\u00DA\u00D1\u00EAY\x12nk\u00B4\u00CD\u009E$*a\u009B\u00A4K\u00CCF\u00BD\u0082'\u00CF\u00AA\u00BF\x00\x03\x00\u00E9O1\u009E\u00B5\u00F0\u00E3\r\x00\x00\x00\x00IEND\u00AEB`\u0082",
    lipstick: "\u0089PNG\r\n\x1A\n\x00\x00\x00\rIHDR\x00\x00\x00\n\x00\x00\x00\n\b\x02\x00\x00\x00\x02PX\u00EA\x00\x00\x00\x19tEXtSoftware\x00Adobe ImageReadyq\u00C9e<\x00\x00\x00HIDATx\u00DAb|\u00D5\u00BD\u008D\u0091\u0091\x01\x17`B\u0092C\u00B0\u00FE\u00FF\u0087I#)\u00FD\u008FP\u00C8\u0088E\x1A\u009B\u00E1@s\u00FE\u00FF\u00C7)\u00CD\u0082\u00C7]\x10\u00C31\u00E5\x19\u0091\u00A51\u008D\u00FE\u008F,\u008Df7#\u009A\u00E1\f\u00A8\u00D6\u00A3\u00A8\x05\b0\x00\u0098\u00E4\x0EC\x1FD\u0086\u00BA\x00\x00\x00\x00IEND\u00AEB`\u0082",
    cuteTeal:  "\u0089PNG\r\n\x1A\n\x00\x00\x00\rIHDR\x00\x00\x00\n\x00\x00\x00\n\b\x02\x00\x00\x00\x02PX\u00EA\x00\x00\x00\x19tEXtSoftware\x00Adobe ImageReadyq\u00C9e<\x00\x00\x00sIDATx\u00DAL\u008F\u00C9\x11\u00C00\b\x03W\x1E\x17\u0093\u00FEk\u00C8/E\x11# \x13\u00FC0\u00C7\u00A2\x11\u00BA\u009E[\"@(\u00E2\u00FC\u00E8\u00D4\u0090\u00B9\u00D85\u00EB\u00F9\f4\u00F9\u00C2\u0091\u0090cr\u008A[\u0099\u00B5\u00A4`T\u00ADr:\u00AB\u009A\u00DE\x0B\x13\u00C9\x05\x1D\u00BBX\u00D7^\u00F1K\u00C2\x0B\u00BD-Z\u00B9<Z\u0089\u00CFZ\u009F\u00F4s\u00A0j\u00A4\u00B5\x18\u00B6MD\u00DD\u00E6\u00C3\u008A\u00AFf\u008A\u00FF9x\x05\x18\x00\u00CB\u00DCI\u00CDE\u00E8V\x19\x00\x00\x00\x00IEND\u00AEB`\u0082",
    sulphur: "\u0089PNG\r\n\x1A\n\x00\x00\x00\rIHDR\x00\x00\x00\n\x00\x00\x00\n\b\x02\x00\x00\x00\x02PX\u00EA\x00\x00\x00\x19tEXtSoftware\x00Adobe ImageReadyq\u00C9e<\x00\x00\x00nIDATx\u00DADOA\x0E\u00C00\b\x12\u00B3\u008F\u00EF\u0085;\u00ECAN\x10\u00D7\u00A6i@\bX\u00BC\u00CF\x1DQ\u00C1\u0083*\x02\x00d\u00C2\u00A9\x11\u00C6\x00+\u00D6\u009A\u00E7?\u00E1\u00A8o\u00D3yu\u00D2\x1A\u00A0\\\u00D9\u00C6\nv\u00A5\u00F0\u00A9l\fg\x11\u00E4\u00F2\u00DA\x14\u00D4\u0082\u00E9\u00A6RV\u00E9\u0083\u00C4\t\u00B8\u00CEO\u00A2\\.)\u00D8\u008E<;\u00EF\u00BF\u00ED\u0093)\u0085H\u00FE\u00A5\u009C\u00A1\u00F7\x13`\x00\x1C\x01?8w\u00B3\x07\x12\x00\x00\x00\x00IEND\u00AEB`\u0082",
    gridGreen: "\u0089PNG\r\n\x1A\n\x00\x00\x00\rIHDR\x00\x00\x00\n\x00\x00\x00\n\b\x02\x00\x00\x00\x02PX\u00EA\x00\x00\x00\x19tEXtSoftware\x00Adobe ImageReadyq\u00C9e<\x00\x00\x00jIDATx\u00DAT\u008E\u00D1\x11\u00C00\bB\u00C5\u00CB\u00BA\x1D\u00A9\u008Bu\x19ZA\u0093+_\u0084\x0BOp=7\x19\x16\x10c\x03\x01\u0092\u00CB\u00E9\tI\u00F4\u00BBLv\u00DAb\x01$\u0087)27\u00FF/\u00A6Q*5\u00E6\u00F3\x1AQ\u00EF\x0F\u00EEz/0e\u00C3R\r\u00CCfw\u00F4UfMa\u00E6\u0083s\u00A2\u00F2u\u00B0&b_\x10|F\u00F5\u00A2\u00C2\u00F3\u009C\x7F\x05\x18\x00pq5\u00FC\u00A0du\u00CD\x00\x00\x00\x00IEND\u00AEB`\u0082",
    white: "\u0089PNG\r\n\x1A\n\x00\x00\x00\rIHDR\x00\x00\x00\n\x00\x00\x00\n\b\x02\x00\x00\x00\x02PX\u00EA\x00\x00\x00\x19tEXtSoftware\x00Adobe ImageReadyq\u00C9e<\x00\x00\x00\x18IDATx\u00DAb\u00FC\u00FF\u00FF?\x03n\u00C0\u00C4\u0080\x17\u008CTi\u0080\x00\x03\x00\u00A5\u00E3\x03\x11\u0086\x14V\u00A5\x00\x00\x00\x00IEND\u00AEB`\u0082"
  } 
} /* END function __defineIconsForUI */





/* Deutsch-Englische Dialogtexte und Fehlermeldungen */
function __defineLocalizeStrings() {
  
  _global.error = { en:"Oops, something went wrong!", 
                    de:"Irgendetwas ist da schiefgelaufen!" }        
  
  _global.uiHead = { en:"Set up baseline grid", 
                     de:"Grundlinienraster einrichten",ru:"Установка сетки из базовых линий" }
                   
  _global.baselineGridLabel = { en:"Baseline grid", 
                                de:"Grundlinienraster", ru: "Сетка из базовых линий"  }   
                              
  _global.valuesTabLabel = { en:"Values", 
                             de:"Werte" }
  
  _global.displayTabLabel = { en:"Display", 
                              de:"Darstellung" }
                   
  _global.startLabel = { en:"Start:", 
                         de:"Anfang:", ru: "Начало"  }  
                      
  _global.inches = { en:"Inch", 
                     de:"Zoll" }
  
  _global.points = { en:"Points", 
                     de:"Punkte", ru: "Пункты"  }
  
  _global.mm = { en:"Millimeters", 
                 de:"Millimeter" } 
  
  _global.cm = { en:"Centimeters", 
                 de:"Zentimeter" }
                   
  _global.picas = { en:"Picas", 
                    de:"Picas" }
                  
  _global.pixels = { en:"Pixels", 
                    de:"Pixel" }
   
  _global.incrementEveryLabel = { en:"Increment every:", 
                                  de:"Einteilung alle:" }                 
  
  _global.relativToLabel = { en:"Relative to:", 
                             de:"Relativ zu:" } 
                           
  _global.topOfThePageListItem = { en:"Top of Page", 
                                   de:"Oberem Seitenrand" }   
                         
  _global.topOfTheMarginListItem = { en:"Top of Margin", 
                                     de:"Kopfsteg" }
                                   
  _global.marginTopLabel = { en:"Top:", 
                             de:"Oben:" }                                
                                   
  _global.marginBottomLabel = { en:"Bottom:", 
                                de:"Unten:" }                                 
    
  _global.marginLeftLabel = { en:"Left:", 
                              de:"Links:" } 
  
  _global.marginRightLabel = { en:"Right:", 
                               de:"Rechts:" }
                             
  _global.marginInsideLabel = { en:"Ins.:", 
                                de:"Innen:" }
  
  _global.marginOutsideLabel = { en:"Outs.:", 
                                 de:"Au\u00dfen:" }
                           
  _global.columnsLabel = { en:"Columns:", 
                           de:"Spalten:" }
  
  _global.numberOfColumnsLabel = { en:"Number:", 
                                  de:"Anzahl:" }                        
                           
  _global.gutterLabel = { en:"Gutter:", 
                          de:"Abstand:" }
                                                     
  _global.viewThresholdLabel = { en:"View Threshold:", 
                                 de:"Anzeigeschwellenwert:", ru: "Показывать в масштабе от" }                         
                           
  _global.percentage = { en:"\u0025", 
                         de:"\u0025" }
                                                   
  _global.baselineColorLabel = { en:"Color:", 
                                 de:"Farbe:", ru: "Цвет" }  
                               
  _global.userDefined = { en:"User-defined", 
                          de:"Benutzerdefiniert" }
  
  _global.userDefinedHelpTip = { en:"User-defined color values", 
                                 de:"Benutzerdefiniert Farbwerte" }
  
  _global.gridsInBackLabel = { en:"Grids in Back", 
                               de:"Raster im Hintergrund" }
  
  _global.noTextFrameSelectedErrorMessage = { en:"Please select one or more text frames on one page!", 
                                              de:"Bitte einen oder mehrere Textrahmen auf einer Seite ausw\u00e4hlen!" }
                                             
  _global.objectStyleNoneName = { fr:"[Aucun]", 
                                  en:"[None]", 
                                  de:"[Ohne]" }
                                
  _global.objectStyleBasicGFName = { fr:"[bloc graphique standard]", 
                                     en:"[Basic Graphics Frame]", 
                                     de:"[Einfacher Grafikrahmen]" }                              
                                
  _global.objectStyleBasicTFName = { fr:"[bloc de texte standard]", 
                                     en:"[Basic Text Frame]", 
                                     de:"[Einfacher Textrahmen]" } 
                         
  _global.objectStyleBasicGridName = { fr:"[grille standard]", 
                                       en:"[Basic Grid]", 
                                       de:"[Einfaches Raster]" }
                             
  _global.basicTFPanelLabel = { en:"Default Text Frame", 
                                de:"Standard-Textrahmen" }
                              
  _global.basicTFObjectStyle = { en:"Object Style:", 
                                 de:"Objektformat:" }
  
  _global.basicTFFirstBaselineLabel = { en:"First Baseline: Offset", 
                                        de:"Erste Grundlinie: Versatz" } 
                                           
  _global.basicTFFirstBaselineMinLabel = { en:"Min:", 
                                           de:"Min:" }  
                                         
  _global.firstBaselineAscentOffset = { en:"Ascent", 
                                        de:"Oberl\u00e4nge" }                                       
                                         
  _global.firstBaselineCapHeight = { en:"Cap Height", 
                                     de:"Versalh\u00f6he" }
                          
  _global.firstBaselineLeadingOffset = { en:"Leading", 
                                         de:"Zeilenabstand" }
                          
  _global.firstBaselineXHeight = { en:"x Height", 
                                   de:"x-H\u00f6he" }
                          
  _global.firstBaselineFixedHeight = { en:"Fixed", 
                                       de:"Fester Wert" }                                       
   
  _global.marginsPanelLabel = { en:"Margins", 
                                de:"Stege (R\u00e4nder)" } 
                              
  _global.marginsTopLabel = { en:"Top", 
                              de:"Oben" }                            
  
  _global.adjustMarginTopHelpTip = { en:"Adjust top margin to selected text frame", 
                                     de:"Oberen Steg (Rand) an ausgew\u00e4hlten Textrahmen anpassen" }
   
  _global.marginsBottomLabel = { en:"Bottom", 
                                 de:"Unten" }
  
  _global.adjustMarginBottomHelpTip = { en:"Adjust bottom margin to selected text frame", 
                                        de:"Unteren Steg (Rand) an ausgew\u00e4hlten Textrahmen anpassen" }
  
  _global.marginsLeftLabel = { en:"Left", 
                               de:"Links" }
  
  _global.adjustMarginLeftHelpTip = { en:"Adjust left margin to selected text frame", 
                                      de:"Linken Steg (Rand) an ausgew\u00e4hlten Textrahmen anpassen" }  
  
  _global.marginsRightLabel = { en:"Right", 
                                de:"Rechts" }
  
  _global.adjustMarginRightHelpTip = { en:"Adjust right margin to selected text frame", 
                                       de:"Rechten Steg (Rand) an ausgew\u00e4hlten Textrahmen anpassen" }
  
  _global.adjustAllMarginsButtonLabel = { en:"All", 
                                          de:"Alle" } 
  
  _global.adjustAllMarginsHelpTip = { en:"Adjust all margins to selected text frame", 
                                      de:"Alle Stege (R\u00e4nder) an ausgew\u00e4hlten Textrahmen anpassen" }
                                    
  _global.setMarginsButtonHelpTip = { en:"Change page margin and column settings manual", 
                                      de:"Stege (R\u00e4nder) und Spalten der Seite manuell \u00e4ndern" }
                                    
  _global.autoMarginsButtonHelpTip = { en:"Change page margin and column settings with script", 
                                       de:"Stege (R\u00e4nder) und Spalten der Seite mittels Skript \u00e4ndern" }
                                     
  _global.marginValueError =  { en:"The value entered for the margin is too large!", 
                                de:"Der eingegebene Wert f\u00fcr den Steg (Rand) ist zu gro\u00df!" }
  
  _global.showGridHelpTip = { en:"Show baseline grid", 
                              de:"Grundlinienraster einblenden" }
                     
  _global.hideGridHelpTip = { en:"Hide baseline grid", 
                              de:"Grundlinienraster ausblenden", ru:"Скрыть сетку из базовых линий" }
                            
  _global.actionPanelLabel = { en:"Actions", 
                               de:"Aktionen" }
                     
  _global.refreshHelpTip = { en:"Refresh display", 
                             de:"Anzeige aktualisieren" } 
                    
  _global.selectionStartHelpTip = { en:"Adjust start of the grid to first baseline of selection", 
                                    de:"Anfang des Rasters an erster Grundlinie der Auswahl ausrichten" } 
                                  
  _global.selectionIncrementHelpTip = { en:"Adjust increment of the grid to leading of selection", 
                                    de:"Abstand der Rasterlinien an Zeilenabstand der Auswahl anpassen" }
                    
  _global.selection = { en:"Selection", 
                        de:"Auswahl" }
                     
  _global.noTextSelectedErrorMessage = { en:"Please select any text object!", 
                                         de:"Bitte ein beliebiges Textobjekt ausw\u00e4hlen!" }
                                       
  _global.flipButtonHelpTip = { en:"Flip margins horizontal", 
                                de:"Stege (R\u00e4nder) horizontal spiegeln" }
                              
  _global.alertNoRightPage = { en:"The active spread has no right page!", 
                               de:"Der aktive Druckbogen hat keine rechte Seite!" }                            
                                                           
  _global.alertNoLeftPage = { en:"The active spread has no left page!", 
                              de:"Der aktive Druckbogen hat keine rechte Seite!" }                            
                              
  _global.alertTooManyPages = { en:"For this action the active spread must have 2 pages!", 
                                de:"F\u00fcr diese Aktion muss der aktive Druckbogen aus 2 Seiten bestehen!" } 
                              
  _global.errorColumnCountValue = { en:"The entered value must be between 1 and 216!", 
                                    de:"Der eingegebene Wert muss zwischen 1 und 216 liegen!" } 
                                  
  _global.errorColumnGutterValue = { en: "Column gutter is too large for this number of columns!",
                                     de: "Spaltenabstand zu groß für diese Spaltenanzahl!"  }
  
  _global.basicTFChangeStyleHint = { en:"These settings change the selected object style!", 
                                     de:"Diese Einstellungen ver\u00e4ndern das ausgew\u00e4hlte Objektformat!" } 
                                       
  _global.cancel = { en:"Close", 
                     de:"Schlie\u00dfen", ru:"Закончить" } 
  
  _global.closeWinHelpTip = { en:"Close Window", 
                              de:"Fenster schlie\u00dfen" }
                            
  _global.uiColors = { LIGHT_BLUE: localize({ en:"Light Blue", de:"Hellblau" }),
                       RED: localize({ en:"Red", de:"Rot" }),
                       GREEN: localize({ en:"Green", de:"Gr\u00fcn" }),
                       BLUE: localize({ en:"Blue", de:"Blau" }),
                       YELLOW: localize({ en:"Yellow", de:"Gelb" }),
                       MAGENTA: localize({ en:"Magenta", de:"Magenta" }),
                       CYAN: localize({ en:"Cyan", de:"Cyan" }),
                       GRAY: localize({ en:"Gray", de:"Grau" }),
                       BLACK: localize({ en:"Black", de:"Schwarz" }),
                       ORANGE: localize({ en:"Orange", de:"Orange" }),
                       DARK_GREEN: localize({ en:"Dark Green", de:"Dunkelgr\u00fcn" }),
                       TEAL: localize({ en:"Teal", de:"T\u00fcrkis" }),
                       TAN: localize({ en:"Tan", de:"Hellbraun" }),
                       BROWN: localize({ en:"Brown", de:"Braun" }),
                       VIOLET: localize({ en:"Violet", de:"Violett" }),
                       GOLD: localize({ en:"Gold", de:"Gold" }),
                       DARK_BLUE: localize({ en:"Dark Blue", de:"Dunkelblau" }),
                       PINK: localize({ en:"Pink", de:"Rosa" }),
                       LAVENDER: localize({ en:"Lavender", de:"Lavendel" }),
                       BRICK_RED: localize({ en:"Brick Red", de:"Rotbraun" }),
                       OLIVE_GREEN: localize({ en:"Olive Green", de:"Olivgr\u00fcn" }),
                       PEACH: localize({ en:"Peach", de:"Aprikot" }),
                       BURGUNDY: localize({ en:"Burgundy", de:"Weinrot" }),
                       GRASS_GREEN: localize({ en:"Grass Green", de:"Grasgr\u00fcn" }),
                       OCHRE: localize({ en:"Ochre", de:"Ocker" }),
                       PURPLE: localize({ en:"Purple", de:"Lila" }),
                       LIGHT_GRAY: localize({ en:"Light Gray", de:"Hellgrau" }),
                       CHARCOAL: localize({ en:"Charcoal", de:"Anthrazit" }),
                       GRID_BLUE: localize({ en:"Grid Blue", de:"Rasterblau" }),
                       GRID_ORANGE: localize({ en:"Grid Orange", de:"Rasterorange" }),
                       FIESTA: localize({ en:"Fiesta", de:"Feuerrot" }),
                       LIGHT_OLIVE: localize({ en:"Light Olive", de:"Helloliv" }),
                       LIPSTICK: localize({ en:"Lipstick", de:"Lippenstift" }),
                       CUTE_TEAL: localize({ en:"Cute Teal", de:"Hellt\u00fcrkis" }),
                       SULPHUR: localize({ en:"Sulphur", de:"Schwefel" }),
                       GRID_GREEN: localize({ en:"Grid Green", de:"Rastergr\u00fcn" }),
                       WHITE: localize({ en:"White", de:"Wei\u00df" }),
                       USER_DEFINED: localize({ en:"User-defined", de:"Benutzerdefiniert" }) }
                          
} /* END function __defineLocalizeStrings */